@@ -22,34 +22,36 @@
 #include "qgslayertree.h"
 #include "qgslayertreelayer.h"
 #include "qgsexpressioncontextutils.h"
+#include "qgsmaplayerutils.h"
+#include "qgsprovidermetadata.h"
 
 ///@cond PRIVATE
 
 int tile2tms( const int y, const int zoom )
 {
   double n = std::pow( 2, zoom );
-  return ( int )std::floor( n - y - 1 );
+  return ( int ) std::floor( n - y - 1 );
 }
 
 int lon2tileX( const double lon, const int z )
 {
-  return ( int )( std::floor( ( lon + 180.0 ) / 360.0 * ( 1 << z ) ) );
+  return ( int ) ( std::floor( ( lon + 180.0 ) / 360.0 * ( 1 << z ) ) );
 }
 
 int lat2tileY( const double lat, const int z )
 {
   double latRad = lat * M_PI / 180.0;
-  return ( int )( std::floor( ( 1.0 - std::asinh( std::tan( latRad ) ) / M_PI ) / 2.0 * ( 1 << z ) ) );
+  return ( int ) ( std::floor( ( 1.0 - std::asinh( std::tan( latRad ) ) / M_PI ) / 2.0 * ( 1 << z ) ) );
 }
 
 double tileX2lon( const int x, const int z )
 {
-  return x / ( double )( 1 << z ) * 360.0 - 180 ;
+  return x / ( double ) ( 1 << z ) * 360.0 - 180;
 }
 
 double tileY2lat( const int y, const int z )
 {
-  double n = M_PI - 2.0 * M_PI * y / ( double )( 1 << z );
+  double n = M_PI - 2.0 * M_PI * y / ( double ) ( 1 << z );
   return 180.0 / M_PI * std::atan( 0.5 * ( std::exp( n ) - std::exp( -n ) ) );
 }
 
@@ -61,21 +63,22 @@ void extent2TileXY( QgsRectangle extent, const int zoom, int &xMin, int &yMin, i
   yMax = lat2tileY( extent.xMaximum(), zoom );
 }
 
-QList< MetaTile > getMetatiles( const QgsRectangle extent, const int zoom, const int tileSize )
+QList<MetaTile> getMetatiles( const QgsRectangle extent, const int zoom, const int tileSize )
 {
   int minX = lon2tileX( extent.xMinimum(), zoom );
   int minY = lat2tileY( extent.yMaximum(), zoom );
   int maxX = lon2tileX( extent.xMaximum(), zoom );
-  int maxY = lat2tileY( extent.yMinimum(), zoom );;
+  int maxY = lat2tileY( extent.yMinimum(), zoom );
+  ;
 
   int i = 0;
-  QMap< QString, MetaTile > tiles;
+  QMap<QString, MetaTile> tiles;
   for ( int x = minX; x <= maxX; x++ )
   {
     int j = 0;
     for ( int y = minY; y <= maxY; y++ )
     {
-      QString key = QStringLiteral( "%1:%2" ).arg( ( int )( i / tileSize ) ).arg( ( int )( j / tileSize ) );
+      QString key = QStringLiteral( "%1:%2" ).arg( ( int ) ( i / tileSize ) ).arg( ( int ) ( j / tileSize ) );
       MetaTile tile = tiles.value( key, MetaTile() );
       tile.addTile( i % tileSize, j % tileSize, Tile( x, y, zoom ) );
       tiles.insert( key, tile );
@@ -122,8 +125,8 @@ bool QgsXyzTilesBaseAlgorithm::prepareAlgorithm( const QVariantMap &parameters,
 
   QgsProject *project = context.project();
 
-  const QList< QgsLayerTreeLayer * > projectLayers = project->layerTreeRoot()->findLayers();
-  QSet< QString > visibleLayers;
+  const QList<QgsLayerTreeLayer *> projectLayers = project->layerTreeRoot()->findLayers();
+  QSet<QString> visibleLayers;
   for ( const QgsLayerTreeLayer *layer : projectLayers )
   {
     if ( layer->isVisible() )
@@ -132,7 +135,7 @@ bool QgsXyzTilesBaseAlgorithm::prepareAlgorithm( const QVariantMap &parameters,
     }
   }
 
-  QList< QgsMapLayer * > renderLayers = project->layerTreeRoot()->layerOrder();
+  QList<QgsMapLayer *> renderLayers = project->layerTreeRoot()->layerOrder();
   for ( QgsMapLayer *layer : renderLayers )
   {
     if ( visibleLayers.contains( layer->id() ) )
@@ -185,6 +188,23 @@ bool QgsXyzTilesBaseAlgorithm::prepareAlgorithm( const QVariantMap &parameters,
   return true;
 }
 
+void QgsXyzTilesBaseAlgorithm::checkLayersUsagePolicy( QgsProcessingFeedback *feedback )
+{
+  if ( mTotalTiles > MAXIMUM_OPENSTREETMAP_TILES_FETCH )
+  {
+    for ( QgsMapLayer *layer : std::as_const( mLayers ) )
+    {
+      if ( QgsMapLayerUtils::isOpenStreetMapLayer( layer ) )
+      {
+        // Prevent bulk downloading of tiles from openstreetmap.org as per OSMF tile usage policy
+        feedback->pushFormattedMessage( QObject::tr( "Layer %1 will be skipped as the algorithm leads to bulk downloading behavior which is prohibited by the %2OpenStreetMap Foundation tile usage policy%3" ).arg( layer->name(), QStringLiteral( "<a href=\"https://operations.osmfoundation.org/policies/tiles/\">" ), QStringLiteral( "</a>" ) ), QObject::tr( "Layer %1 will be skipped as the algorithm leads to bulk downloading behavior which is prohibited by the %2OpenStreetMap Foundation tile usage policy%3" ).arg( layer->name(), QString(), QString() ) );
+        mLayers.removeAll( layer );
+        delete layer;
+      }
+    }
+  }
+}
+
 void QgsXyzTilesBaseAlgorithm::startJobs()
 {
   while ( mRendererJobs.size() < mThreadsNumber && !mMetaTiles.empty() )
@@ -216,7 +236,7 @@ void QgsXyzTilesBaseAlgorithm::startJobs()
 
     QgsMapRendererSequentialJob *job = new QgsMapRendererSequentialJob( settings );
     mRendererJobs.insert( job, metaTile );
-    QObject::connect( job, &QgsMapRendererJob::finished, mFeedback, [ this, job ]() { processMetaTile( job ); } );
+    QObject::connect( job, &QgsMapRendererJob::finished, mFeedback, [this, job]() { processMetaTile( job ); } );
     job->start();
   }
 }
@@ -255,13 +275,13 @@ void QgsXyzTilesDirectoryAlgorithm::initAlgorithm( const QVariantMap & )
   addParameter( new QgsProcessingParameterNumber( QStringLiteral( "TILE_HEIGHT" ), QObject::tr( "Tile height" ), Qgis::ProcessingNumberParameterType::Integer, 256, false, 1, 4096 ) );
   addParameter( new QgsProcessingParameterBoolean( QStringLiteral( "TMS_CONVENTION" ), QObject::tr( "Use inverted tile Y axis (TMS convention)" ), false, true ) );
 
-  std::unique_ptr< QgsProcessingParameterString > titleParam = std::make_unique< QgsProcessingParameterString >( QStringLiteral( "HTML_TITLE" ), QObject::tr( "Leaflet HTML output title" ), QVariant(), false, true );
+  std::unique_ptr<QgsProcessingParameterString> titleParam = std::make_unique<QgsProcessingParameterString>( QStringLiteral( "HTML_TITLE" ), QObject::tr( "Leaflet HTML output title" ), QVariant(), false, true );
   titleParam->setFlags( titleParam->flags() | Qgis::ProcessingParameterFlag::Advanced );
   addParameter( titleParam.release() );
-  std::unique_ptr< QgsProcessingParameterString > attributionParam = std::make_unique< QgsProcessingParameterString >( QStringLiteral( "HTML_ATTRIBUTION" ), QObject::tr( "Leaflet HTML output attribution" ), QVariant(), false, true );
+  std::unique_ptr<QgsProcessingParameterString> attributionParam = std::make_unique<QgsProcessingParameterString>( QStringLiteral( "HTML_ATTRIBUTION" ), QObject::tr( "Leaflet HTML output attribution" ), QVariant(), false, true );
   attributionParam->setFlags( attributionParam->flags() | Qgis::ProcessingParameterFlag::Advanced );
   addParameter( attributionParam.release() );
-  std::unique_ptr< QgsProcessingParameterBoolean > osmParam = std::make_unique< QgsProcessingParameterBoolean >( QStringLiteral( "HTML_OSM" ), QObject::tr( "Include OpenStreetMap basemap in Leaflet HTML output" ), false, true );
+  std::unique_ptr<QgsProcessingParameterBoolean> osmParam = std::make_unique<QgsProcessingParameterBoolean>( QStringLiteral( "HTML_OSM" ), QObject::tr( "Include OpenStreetMap basemap in Leaflet HTML output" ), false, true );
   osmParam->setFlags( osmParam->flags() | Qgis::ProcessingParameterFlag::Advanced );
   addParameter( osmParam.release() );
 
@@ -281,21 +301,25 @@ QVariantMap QgsXyzTilesDirectoryAlgorithm::processAlgorithm( const QVariantMap &
   mOutputDir = outputDir;
   mTms = tms;
 
+  mTotalTiles = 0;
   for ( int z = mMinZoom; z <= mMaxZoom; z++ )
   {
     if ( feedback->isCanceled() )
       break;
 
     mMetaTiles += getMetatiles( mWgs84Extent, z, mMetaTileSize );
+    feedback->pushWarning( QObject::tr( "%1 tiles will be created for zoom level %2" ).arg( mMetaTiles.size() - mTotalTiles ).arg( z ) );
+    mTotalTiles = mMetaTiles.size();
   }
+  feedback->pushWarning( QObject::tr( "A total of %1 tiles will be created" ).arg( mTotalTiles ) );
+
+  checkLayersUsagePolicy( feedback );
 
   for ( QgsMapLayer *layer : std::as_const( mLayers ) )
   {
     layer->moveToThread( QThread::currentThread() );
   }
 
-  mTotalTiles = mMetaTiles.size();
-
   QEventLoop loop;
   // cppcheck-suppress danglingLifetime
   mEventLoop = &loop;
@@ -312,23 +336,26 @@ QVariantMap QgsXyzTilesDirectoryAlgorithm::processAlgorithm( const QVariantMap &
   {
     QString osm = QStringLiteral(
                     "var osm_layer = L.tileLayer('https://tile.openstreetmap.org/{z}/{x}/{y}.png',"
-                    "{minZoom: %1, maxZoom: %2, attribution: '&copy; <a href=\"https://www.openstreetmap.org/copyright\">OpenStreetMap</a> contributors'}).addTo(map);" )
-                  .arg( mMinZoom ).arg( mMaxZoom );
+                    "{minZoom: %1, maxZoom: %2, attribution: '&copy; <a href=\"https://www.openstreetmap.org/copyright\">OpenStreetMap</a> contributors'}).addTo(map);"
+    )
+                    .arg( mMinZoom )
+                    .arg( mMaxZoom );
 
     QString addOsm = useOsm ? osm : QString();
     QString tmsConvention = tms ? QStringLiteral( "true" ) : QStringLiteral( "false" );
     QString attr = attribution.isEmpty() ? QStringLiteral( "Created by QGIS" ) : attribution;
     QString tileSource = QStringLiteral( "'file:///%1/{z}/{x}/{y}.%2'" )
-                         .arg( outputDir.replace( "\\", "/" ).toHtmlEscaped() ).arg( mTileFormat.toLower() );
+                           .arg( outputDir.replace( "\\", "/" ).toHtmlEscaped() )
+                           .arg( mTileFormat.toLower() );
 
     QString html = QStringLiteral(
                      "<!DOCTYPE html><html><head><title>%1</title><meta charset=\"utf-8\"/>"
                      "<meta name=\"viewport\" content=\"width=device-width, initial-scale=1.0\">"
-                     "<link rel=\"stylesheet\" href=\"https://unpkg.com/leaflet@1.9.3/dist/leaflet.css\""
-                     "integrity=\"sha384-o/2yZuJZWGJ4s/adjxVW71R+EO/LyCwdQfP5UWSgX/w87iiTXuvDZaejd3TsN7mf\""
+                     "<link rel=\"stylesheet\" href=\"https://unpkg.com/leaflet@1.9.4/dist/leaflet.css\""
+                     "integrity=\"sha384-sHL9NAb7lN7rfvG5lfHpm643Xkcjzp4jFvuavGOndn6pjVqS6ny56CAt3nsEVT4H\""
                      "crossorigin=\"\"/>"
-                     "<script src=\"https://unpkg.com/leaflet@1.9.3/dist/leaflet.js\""
-                     "integrity=\"sha384-okbbMvvx/qfQkmiQKfd5VifbKZ/W8p1qIsWvE1ROPUfHWsDcC8/BnHohF7vPg2T6\""
+                     "<script src=\"https://unpkg.com/leaflet@1.9.4/dist/leaflet.js\""
+                     "integrity=\"sha384-cxOPjt7s7Iz04uaHJceBmS+qpjv2JkIHNVcuOrM+YHwZOmJGBXI00mdUXEq65HTH\""
                      "crossorigin=\"\"></script>"
                      "<style type=\"text/css\">body {margin: 0;padding: 0;} html, body, #map{width: 100%;height: 100%;}</style></head>"
                      "<body><div id=\"map\"></div><script>"
@@ -337,17 +364,17 @@ QVariantMap QgsXyzTilesDirectoryAlgorithm::processAlgorithm( const QVariantMap &
                      "%5"
                      "var tilesource_layer = L.tileLayer(%6, {minZoom: %7, maxZoom: %8, tms: %9, attribution: '%10'}).addTo(map);"
                      "</script></body></html>"
-                   )
-                   .arg( title.isEmpty() ? QStringLiteral( "Leaflet preview" ) : title )
-                   .arg( mWgs84Extent.center().y() )
-                   .arg( mWgs84Extent.center().x() )
-                   .arg( ( mMaxZoom + mMinZoom ) / 2 )
-                   .arg( addOsm )
-                   .arg( tileSource )
-                   .arg( mMinZoom )
-                   .arg( mMaxZoom )
-                   .arg( tmsConvention )
-                   .arg( attr );
+    )
+                     .arg( title.isEmpty() ? QStringLiteral( "Leaflet preview" ) : title )
+                     .arg( mWgs84Extent.center().y() )
+                     .arg( mWgs84Extent.center().x() )
+                     .arg( ( mMaxZoom + mMinZoom ) / 2 )
+                     .arg( addOsm )
+                     .arg( tileSource )
+                     .arg( mMinZoom )
+                     .arg( mMaxZoom )
+                     .arg( tmsConvention )
+                     .arg( attr );
 
     QFile htmlFile( outputHtml );
     if ( !htmlFile.open( QIODevice::WriteOnly | QIODevice::Truncate ) )
@@ -355,7 +382,7 @@ QVariantMap QgsXyzTilesDirectoryAlgorithm::processAlgorithm( const QVariantMap &
       throw QgsProcessingException( QObject::tr( "Could not open html file %1" ).arg( outputHtml ) );
     }
     QTextStream fout( &htmlFile );
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
+#if QT_VERSION < QT_VERSION_CHECK( 6, 0, 0 )
     fout.setCodec( "UTF-8" );
 #endif
     fout << html;
@@ -403,7 +430,10 @@ void QgsXyzTilesDirectoryAlgorithm::processMetaTile( QgsMapRendererSequentialJob
       j->deleteLater();
     }
     mRendererJobs.clear();
-    mEventLoop->exit();
+    if ( mEventLoop )
+    {
+      mEventLoop->exit();
+    }
     return;
   }
 
@@ -413,7 +443,10 @@ void QgsXyzTilesDirectoryAlgorithm::processMetaTile( QgsMapRendererSequentialJob
   }
   else if ( mMetaTiles.size() == 0 && mRendererJobs.size() == 0 )
   {
-    mEventLoop->exit();
+    if ( mEventLoop )
+    {
+      mEventLoop->exit();
+    }
   }
 }
 
@@ -460,25 +493,36 @@ QVariantMap QgsXyzTilesMbtilesAlgorithm::processAlgorithm( const QVariantMap &pa
     throw QgsProcessingException( QObject::tr( "Failed to create MBTiles file %1" ).arg( outputFile ) );
   }
   mMbtilesWriter->setMetadataValue( "format", mTileFormat.toLower() );
-  mMbtilesWriter->setMetadataValue( "name",  QFileInfo( outputFile ).baseName() );
-  mMbtilesWriter->setMetadataValue( "version",  QStringLiteral( "1.1" ) );
+  mMbtilesWriter->setMetadataValue( "name", QFileInfo( outputFile ).baseName() );
+  mMbtilesWriter->setMetadataValue( "version", QStringLiteral( "1.1" ) );
   mMbtilesWriter->setMetadataValue( "type", QStringLiteral( "overlay" ) );
   mMbtilesWriter->setMetadataValue( "minzoom", QString::number( mMinZoom ) );
   mMbtilesWriter->setMetadataValue( "maxzoom", QString::number( mMaxZoom ) );
   QString boundsStr = QString( "%1,%2,%3,%4" )
-                      .arg( mWgs84Extent.xMinimum() ).arg( mWgs84Extent.yMinimum() )
-                      .arg( mWgs84Extent.xMaximum() ).arg( mWgs84Extent.yMaximum() );
-  mMbtilesWriter->setMetadataValue( "bounds",  boundsStr );
+                        .arg( mWgs84Extent.xMinimum() )
+                        .arg( mWgs84Extent.yMinimum() )
+                        .arg( mWgs84Extent.xMaximum() )
+                        .arg( mWgs84Extent.yMaximum() );
+  mMbtilesWriter->setMetadataValue( "bounds", boundsStr );
 
+  mTotalTiles = 0;
   for ( int z = mMinZoom; z <= mMaxZoom; z++ )
   {
     if ( feedback->isCanceled() )
       break;
 
     mMetaTiles += getMetatiles( mWgs84Extent, z, mMetaTileSize );
+    feedback->pushInfo( QObject::tr( "%1 tiles will be created for zoom level %2" ).arg( mMetaTiles.size() - mTotalTiles ).arg( z ) );
+    mTotalTiles = mMetaTiles.size();
   }
+  feedback->pushInfo( QObject::tr( "A total of %1 tiles will be created" ).arg( mTotalTiles ) );
 
-  mTotalTiles = mMetaTiles.size();
+  checkLayersUsagePolicy( feedback );
+
+  for ( QgsMapLayer *layer : std::as_const( mLayers ) )
+  {
+    layer->moveToThread( QThread::currentThread() );
+  }
 
   QEventLoop loop;
   // cppcheck-suppress danglingLifetime
@@ -486,6 +530,9 @@ QVariantMap QgsXyzTilesMbtilesAlgorithm::processAlgorithm( const QVariantMap &pa
   startJobs();
   loop.exec();
 
+  qDeleteAll( mLayers );
+  mLayers.clear();
+
   QVariantMap results;
   results.insert( QStringLiteral( "OUTPUT_FILE" ), outputFile );
   return results;
@@ -525,7 +572,10 @@ void QgsXyzTilesMbtilesAlgorithm::processMetaTile( QgsMapRendererSequentialJob *
       j->deleteLater();
     }
     mRendererJobs.clear();
-    mEventLoop->exit();
+    if ( mEventLoop )
+    {
+      mEventLoop->exit();
+    }
     return;
   }
 
@@ -535,7 +585,10 @@ void QgsXyzTilesMbtilesAlgorithm::processMetaTile( QgsMapRendererSequentialJob *
   }
   else if ( mMetaTiles.size() == 0 && mRendererJobs.size() == 0 )
   {
-    mEventLoop->exit();
+    if ( mEventLoop )
+    {
+      mEventLoop->exit();
+    }
   }
 }
 
