@@ -64,6 +64,7 @@
 #include "qgstransformsettingsdialog.h"
 
 #include "qgsgeorefmainwindow.h"
+#include "moc_qgsgeorefmainwindow.cpp"
 #include "qgsmessagebar.h"
 #include "qgsvectorwarper.h"
 #include "qgsscreenhelper.h"
@@ -201,10 +202,7 @@ void QgsGeoreferencerMainWindow::closeEvent( QCloseEvent *e )
 
 void QgsGeoreferencerMainWindow::reset()
 {
-  if ( QMessageBox::question( this,
-                              tr( "Reset Georeferencer" ),
-                              tr( "Reset georeferencer and clear all GCP points?" ),
-                              QMessageBox::Ok | QMessageBox::Cancel, QMessageBox::Cancel ) != QMessageBox::Cancel )
+  if ( QMessageBox::question( this, tr( "Reset Georeferencer" ), tr( "Reset georeferencer and clear all GCP points?" ), QMessageBox::Ok | QMessageBox::Cancel, QMessageBox::Cancel ) != QMessageBox::Cancel )
   {
     mFileName.clear();
     mModifiedFileName.clear();
@@ -243,7 +241,6 @@ void QgsGeoreferencerMainWindow::openLayer( Qgis::LayerType layerType, const QSt
     QString otherFiles = tr( "All other files (*)" );
     switch ( layerType )
     {
-
       case Qgis::LayerType::Raster:
       {
         QString lastUsedFilter = settingLastRasterFileFilter->value();
@@ -320,8 +317,7 @@ void QgsGeoreferencerMainWindow::openLayer( Qgis::LayerType layerType, const QSt
     case Qgis::LayerType::Raster:
       if ( !QgsRasterLayer::isValidRasterFileName( mFileName, errMsg ) )
       {
-        mMessageBar->pushMessage( tr( "Open Raster" ), tr( "%1 is not a supported raster data source.%2" ).arg( mFileName,
-                                  !errMsg.isEmpty() ? QStringLiteral( " (%1)" ).arg( errMsg ) : QString() ), Qgis::MessageLevel::Critical );
+        mMessageBar->pushMessage( tr( "Open Raster" ), tr( "%1 is not a supported raster data source.%2" ).arg( mFileName, !errMsg.isEmpty() ? QStringLiteral( " (%1)" ).arg( errMsg ) : QString() ), Qgis::MessageLevel::Critical );
         return;
       }
       break;
@@ -374,7 +370,7 @@ void QgsGeoreferencerMainWindow::openLayer( Qgis::LayerType layerType, const QSt
   // load previously added points
   mGCPpointsFileName = mFileName + ".points";
   QString error;
-  ( void )loadGCPs( error );
+  ( void ) loadGCPs( error );
 
   if ( mLayer )
     mCanvas->setExtent( mLayer->extent() );
@@ -406,7 +402,7 @@ void QgsGeoreferencerMainWindow::dropEvent( QDropEvent *event )
 
   // get the file list
   QList<QUrl>::iterator i;
-  QList<QUrl>urls = event->mimeData()->urls();
+  QList<QUrl> urls = event->mimeData()->urls();
   QString file;
   for ( i = urls.begin(); i != urls.end(); ++i )
   {
@@ -420,8 +416,7 @@ void QgsGeoreferencerMainWindow::dropEvent( QDropEvent *event )
     }
   }
 
-  connect( timer, &QTimer::timeout, this, [this, timer, file]
-  {
+  connect( timer, &QTimer::timeout, this, [this, timer, file] {
     // TODO -- consider using querySublayers to determine this instead
     if ( QgsRasterLayer::isValidRasterFileName( file ) )
       openLayer( Qgis::LayerType::Raster, file );
@@ -530,8 +525,7 @@ void QgsGeoreferencerMainWindow::generateGDALScript()
           int order = polynomialOrder( mTransformMethod );
           if ( order != 0 )
           {
-            gdalwarpCommand = generateGDALwarpCommand( resamplingStr, mCompressionMethod, mUseZeroForTrans, order,
-                              mUserResX, mUserResY );
+            gdalwarpCommand = generateGDALwarpCommand( resamplingStr, mCompressionMethod, mUseZeroForTrans, order, mUserResX, mUserResY );
             showGDALScript( QStringList() << translateCommand << gdalwarpCommand );
           }
           else
@@ -570,9 +564,7 @@ void QgsGeoreferencerMainWindow::generateGDALScript()
 
   if ( isIncompatibleTransformMethod )
   {
-    mMessageBar->pushMessage( tr( "Invalid Transform" ), tr( "GDAL scripting is not supported for %1 transformation." )
-                              .arg( QgsGcpTransformerInterface::methodToString( mTransformMethod ) )
-                              , Qgis::MessageLevel::Critical );
+    mMessageBar->pushMessage( tr( "Invalid Transform" ), tr( "GDAL scripting is not supported for %1 transformation." ).arg( QgsGcpTransformerInterface::methodToString( mTransformMethod ) ), Qgis::MessageLevel::Critical );
   }
 }
 
@@ -654,8 +646,7 @@ void QgsGeoreferencerMainWindow::linkGeorefToQgis( bool link )
   }
 }
 
-void QgsGeoreferencerMainWindow::addPoint( const QgsPointXY &sourceCoords, const QgsPointXY &destinationMapCoords, const QgsCoordinateReferenceSystem &destinationCrs,
-    bool enable, bool finalize )
+void QgsGeoreferencerMainWindow::addPoint( const QgsPointXY &sourceCoords, const QgsPointXY &destinationMapCoords, const QgsCoordinateReferenceSystem &destinationCrs, bool enable, bool finalize )
 {
   QgsGeorefDataPoint *pnt = new QgsGeorefDataPoint( mCanvas, QgisApp::instance()->mapCanvas(), sourceCoords, destinationMapCoords, destinationCrs, enable );
   mPoints.append( pnt );
@@ -775,12 +766,10 @@ void QgsGeoreferencerMainWindow::showCoordDialog( const QgsPointXY &sourceCoordi
   {
     mNewlyAddedPoint = new QgsGeorefDataPoint( mCanvas, QgisApp::instance()->mapCanvas(), sourceCoordinates, QgsPointXY(), QgsCoordinateReferenceSystem(), true );
     mMapCoordsDialog = new QgsMapCoordsDialog( QgisApp::instance()->mapCanvas(), mNewlyAddedPoint, lastProjection, this );
-    connect( mMapCoordsDialog, &QgsMapCoordsDialog::pointAdded, this, [ = ]( const QgsPointXY & sourceLayerCoordinate, const QgsPointXY & destinationCoordinate, const QgsCoordinateReferenceSystem & destinationCrs )
-    {
+    connect( mMapCoordsDialog, &QgsMapCoordsDialog::pointAdded, this, [=]( const QgsPointXY &sourceLayerCoordinate, const QgsPointXY &destinationCoordinate, const QgsCoordinateReferenceSystem &destinationCrs ) {
       addPoint( sourceLayerCoordinate, destinationCoordinate, destinationCrs );
     } );
-    connect( mMapCoordsDialog, &QObject::destroyed, this, [ = ]
-    {
+    connect( mMapCoordsDialog, &QObject::destroyed, this, [=] {
       delete mNewlyAddedPoint;
       mNewlyAddedPoint = nullptr;
     } );
@@ -795,8 +784,7 @@ void QgsGeoreferencerMainWindow::showCoordDialog( const QgsPointXY &sourceCoordi
 void QgsGeoreferencerMainWindow::loadGCPsDialog()
 {
   QString selectedFile = mFileName.isEmpty() ? QString() : mFileName + ".points";
-  mGCPpointsFileName = QFileDialog::getOpenFileName( this, tr( "Load GCP Points" ),
-                       selectedFile, tr( "GCP file" ) + " (*.points)" );
+  mGCPpointsFileName = QFileDialog::getOpenFileName( this, tr( "Load GCP Points" ), selectedFile, tr( "GCP file" ) + " (*.points)" );
   if ( mGCPpointsFileName.isEmpty() )
     return;
 
@@ -820,9 +808,7 @@ void QgsGeoreferencerMainWindow::saveGCPsDialog()
   }
 
   QString selectedFile = mFileName.isEmpty() ? QString() : mFileName + ".points";
-  mGCPpointsFileName = QFileDialog::getSaveFileName( this, tr( "Save GCP Points" ),
-                       selectedFile,
-                       tr( "GCP file" ) + " (*.points)" );
+  mGCPpointsFileName = QFileDialog::getSaveFileName( this, tr( "Save GCP Points" ), selectedFile, tr( "GCP file" ) + " (*.points)" );
 
   if ( mGCPpointsFileName.isEmpty() )
     return;
@@ -1008,9 +994,9 @@ void QgsGeoreferencerMainWindow::createActions()
   connect( mActionReset, &QAction::triggered, this, &QgsGeoreferencerMainWindow::reset );
 
   mActionOpenRaster->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionAddRasterLayer.svg" ) ) );
-  connect( mActionOpenRaster, &QAction::triggered, this, [ = ] { openLayer( Qgis::LayerType::Raster ); } );
+  connect( mActionOpenRaster, &QAction::triggered, this, [=] { openLayer( Qgis::LayerType::Raster ); } );
 
-  connect( mActionOpenVector, &QAction::triggered, this, [ = ] { openLayer( Qgis::LayerType::Vector ); } );
+  connect( mActionOpenVector, &QAction::triggered, this, [=] { openLayer( Qgis::LayerType::Vector ); } );
 
   mActionStartGeoref->setIcon( QgsApplication::getThemeIcon( QStringLiteral( "/mActionStart.svg" ) ) );
   connect( mActionStartGeoref, &QAction::triggered, this, &QgsGeoreferencerMainWindow::georeference );
@@ -1077,8 +1063,7 @@ void QgsGeoreferencerMainWindow::createActions()
   connect( mActionFullHistogramStretch, &QAction::triggered, this, &QgsGeoreferencerMainWindow::fullHistogramStretch );
   mActionFullHistogramStretch->setEnabled( false );
 
-  mActionQuit->setShortcuts( QList<QKeySequence>() << QKeySequence( QStringLiteral( "CTRL+Q" ) )
-                             << QKeySequence( Qt::Key_Escape ) );
+  mActionQuit->setShortcuts( QList<QKeySequence>() << QKeySequence( QStringLiteral( "CTRL+Q" ) ) << QKeySequence( Qt::Key_Escape ) );
   connect( mActionQuit, &QAction::triggered, this, &QWidget::close );
 }
 
@@ -1126,32 +1111,24 @@ void QgsGeoreferencerMainWindow::createMapCanvas()
 
   mToolAddPoint = new QgsGeorefToolAddPoint( mCanvas );
   mToolAddPoint->setAction( mActionAddPoint );
-  connect( mToolAddPoint, &QgsGeorefToolAddPoint::showCoordDialog,
-           this, &QgsGeoreferencerMainWindow::showCoordDialog );
+  connect( mToolAddPoint, &QgsGeorefToolAddPoint::showCoordDialog, this, &QgsGeoreferencerMainWindow::showCoordDialog );
 
   mToolDeletePoint = new QgsGeorefToolDeletePoint( mCanvas );
   mToolDeletePoint->setAction( mActionDeletePoint );
-  connect( mToolDeletePoint, &QgsGeorefToolDeletePoint::deleteDataPoint,
-           this, static_cast<void ( QgsGeoreferencerMainWindow::* )( QPoint )>( &QgsGeoreferencerMainWindow::deleteDataPoint ) );
+  connect( mToolDeletePoint, &QgsGeorefToolDeletePoint::deleteDataPoint, this, static_cast<void ( QgsGeoreferencerMainWindow::* )( QPoint )>( &QgsGeoreferencerMainWindow::deleteDataPoint ) );
 
   mToolMovePoint = new QgsGeorefToolMovePoint( mCanvas );
   mToolMovePoint->setAction( mActionMoveGCPPoint );
-  connect( mToolMovePoint, &QgsGeorefToolMovePoint::pointPressed,
-           this, &QgsGeoreferencerMainWindow::selectPoint );
-  connect( mToolMovePoint, &QgsGeorefToolMovePoint::pointMoved,
-           this, &QgsGeoreferencerMainWindow::movePoint );
-  connect( mToolMovePoint, &QgsGeorefToolMovePoint::pointReleased,
-           this, &QgsGeoreferencerMainWindow::releasePoint );
+  connect( mToolMovePoint, &QgsGeorefToolMovePoint::pointPressed, this, &QgsGeoreferencerMainWindow::selectPoint );
+  connect( mToolMovePoint, &QgsGeorefToolMovePoint::pointMoved, this, &QgsGeoreferencerMainWindow::movePoint );
+  connect( mToolMovePoint, &QgsGeorefToolMovePoint::pointReleased, this, &QgsGeoreferencerMainWindow::releasePoint );
 
   // Point in QGIS Map
   mToolMovePointQgis = new QgsGeorefToolMovePoint( QgisApp::instance()->mapCanvas() );
   mToolMovePointQgis->setAction( mActionMoveGCPPoint );
-  connect( mToolMovePointQgis, &QgsGeorefToolMovePoint::pointPressed,
-           this, &QgsGeoreferencerMainWindow::selectPoint );
-  connect( mToolMovePointQgis, &QgsGeorefToolMovePoint::pointMoved,
-           this, &QgsGeoreferencerMainWindow::movePoint );
-  connect( mToolMovePointQgis, &QgsGeorefToolMovePoint::pointReleased,
-           this, &QgsGeoreferencerMainWindow::releasePoint );
+  connect( mToolMovePointQgis, &QgsGeorefToolMovePoint::pointPressed, this, &QgsGeoreferencerMainWindow::selectPoint );
+  connect( mToolMovePointQgis, &QgsGeorefToolMovePoint::pointMoved, this, &QgsGeoreferencerMainWindow::movePoint );
+  connect( mToolMovePointQgis, &QgsGeorefToolMovePoint::pointReleased, this, &QgsGeoreferencerMainWindow::releasePoint );
 
   QgsSettings s;
   double zoomFactor = s.value( QStringLiteral( "/qgis/zoom_factor" ), 2 ).toDouble();
@@ -1171,8 +1148,7 @@ void QgsGeoreferencerMainWindow::createMapCanvas()
 void QgsGeoreferencerMainWindow::createMenus()
 {
   // Get platform for menu layout customization (Gnome, Kde, Mac, Win)
-  QDialogButtonBox::ButtonLayout layout =
-    QDialogButtonBox::ButtonLayout( style()->styleHint( QStyle::SH_DialogButtonLayout, nullptr, this ) );
+  QDialogButtonBox::ButtonLayout layout = QDialogButtonBox::ButtonLayout( style()->styleHint( QStyle::SH_DialogButtonLayout, nullptr, this ) );
 
   mPanelMenu = new QMenu( tr( "Panels" ) );
   mPanelMenu->setObjectName( QStringLiteral( "mPanelMenu" ) );
@@ -1211,8 +1187,7 @@ void QgsGeoreferencerMainWindow::createDockWidgets()
   dockWidgetGCPpoints->setWidget( mGCPListWidget );
 
   connect( mGCPListWidget, &QgsGCPListWidget::jumpToGCP, this, &QgsGeoreferencerMainWindow::recenterOnPoint );
-  connect( mGCPListWidget, static_cast<void ( QgsGCPListWidget::* )( int )>( &QgsGCPListWidget::deleteDataPoint ),
-           this, static_cast<void ( QgsGeoreferencerMainWindow::* )( int )>( &QgsGeoreferencerMainWindow::deleteDataPoint ) );
+  connect( mGCPListWidget, static_cast<void ( QgsGCPListWidget::* )( int )>( &QgsGCPListWidget::deleteDataPoint ), this, static_cast<void ( QgsGeoreferencerMainWindow::* )( int )>( &QgsGeoreferencerMainWindow::deleteDataPoint ) );
   connect( mGCPListWidget, &QgsGCPListWidget::pointEnabled, this, &QgsGeoreferencerMainWindow::updateGeorefTransform );
 }
 
@@ -1292,7 +1267,7 @@ void QgsGeoreferencerMainWindow::setupConnections()
   connect( mCanvas, &QgsMapCanvas::zoomNextStatusChanged, mActionZoomNext, &QAction::setEnabled );
 
   // Connect mapCanvas rotation widget
-  connect( mRotationEdit, static_cast < void ( QgsDoubleSpinBox::* )( double ) > ( &QgsDoubleSpinBox::valueChanged ), this, &QgsGeoreferencerMainWindow::updateCanvasRotation );
+  connect( mRotationEdit, static_cast<void ( QgsDoubleSpinBox::* )( double )>( &QgsDoubleSpinBox::valueChanged ), this, &QgsGeoreferencerMainWindow::updateCanvasRotation );
   connect( QgisApp::instance()->mapCanvas(), &QgsMapCanvas::destinationCrsChanged, this, &QgsGeoreferencerMainWindow::invalidateCanvasCoords );
 }
 
@@ -1315,7 +1290,7 @@ void QgsGeoreferencerMainWindow::loadSource( Qgis::LayerType layerType, const QS
       QgsVectorLayer::LayerOptions options( QgsProject::instance()->transformContext() );
       // never prompt for a crs selection for the input layer!
       options.skipCrsValidation = true;
-      mLayer = std::make_unique< QgsVectorLayer >( uri, QStringLiteral( "Vector" ), provider, options );
+      mLayer = std::make_unique<QgsVectorLayer>( uri, QStringLiteral( "Vector" ), provider, options );
       break;
     }
 
@@ -1324,7 +1299,7 @@ void QgsGeoreferencerMainWindow::loadSource( Qgis::LayerType layerType, const QS
       QgsRasterLayer::LayerOptions options( true, QgsProject::instance()->transformContext() );
       // never prompt for a crs selection for the input raster!
       options.skipCrsValidation = true;
-      mLayer = std::make_unique< QgsRasterLayer >( uri, QStringLiteral( "Raster" ), provider, options );
+      mLayer = std::make_unique<QgsRasterLayer>( uri, QStringLiteral( "Raster" ), provider, options );
       break;
     }
 
@@ -1419,10 +1394,7 @@ void QgsGeoreferencerMainWindow::writeSettings()
 bool QgsGeoreferencerMainWindow::loadGCPs( QString &error )
 {
   QgsCoordinateReferenceSystem actualDestinationCrs;
-  const QList< QgsGcpPoint > points = QgsGCPList::loadGcps( mGCPpointsFileName,
-                                      mTargetCrs,
-                                      actualDestinationCrs,
-                                      error );
+  const QList<QgsGcpPoint> points = QgsGCPList::loadGcps( mGCPpointsFileName, mTargetCrs, actualDestinationCrs, error );
   if ( !error.isEmpty() )
     return false;
 
@@ -1467,10 +1439,7 @@ QgsGeoreferencerMainWindow::SaveGCPs QgsGeoreferencerMainWindow::checkNeedGCPSav
 
   if ( !equalGCPlists( mSavedPoints, mPoints ) )
   {
-    QMessageBox::StandardButton a = QMessageBox::question( this, tr( "Save GCPs" ),
-                                    tr( "Save GCP points?" ),
-                                    QMessageBox::Save | QMessageBox::Discard
-                                    | QMessageBox::Cancel );
+    QMessageBox::StandardButton a = QMessageBox::question( this, tr( "Save GCPs" ), tr( "Save GCP points?" ), QMessageBox::Save | QMessageBox::Discard | QMessageBox::Cancel );
     if ( a == QMessageBox::Save )
     {
       return QgsGeoreferencerMainWindow::GCPSAVE;
@@ -1488,8 +1457,7 @@ bool QgsGeoreferencerMainWindow::georeference()
   if ( !validate() )
     return false;
 
-  if ( mLayer->type() == Qgis::LayerType::Raster && mCreateWorldFileOnly && ( QgsGcpTransformerInterface::TransformMethod::Linear == mGeorefTransform.transformParametrisation() ||
-       QgsGcpTransformerInterface::TransformMethod::Helmert == mGeorefTransform.transformParametrisation() ) )
+  if ( mLayer->type() == Qgis::LayerType::Raster && mCreateWorldFileOnly && ( QgsGcpTransformerInterface::TransformMethod::Linear == mGeorefTransform.transformParametrisation() || QgsGcpTransformerInterface::TransformMethod::Helmert == mGeorefTransform.transformParametrisation() ) )
   {
     QgsPointXY origin;
     double pixelXSize, pixelYSize, rotation;
@@ -1503,12 +1471,10 @@ bool QgsGeoreferencerMainWindow::georeference()
     {
       if ( QFile::exists( mWorldFileName ) )
       {
-        int r = QMessageBox::question( this, tr( "Georeference" ),
-                                       tr( "<p>The selected file already seems to have a "
-                                           "world file! Do you want to replace it with the "
-                                           "new world file?</p>" ),
-                                       QMessageBox::Yes | QMessageBox::Default,
-                                       QMessageBox::No | QMessageBox::Escape );
+        int r = QMessageBox::question( this, tr( "Georeference" ), tr( "<p>The selected file already seems to have a "
+                                                                       "world file! Do you want to replace it with the "
+                                                                       "new world file?</p>" ),
+                                       QMessageBox::Yes | QMessageBox::Default, QMessageBox::No | QMessageBox::Escape );
         if ( r == QMessageBox::No )
           return false;
         else
@@ -1554,7 +1520,6 @@ bool QgsGeoreferencerMainWindow::georeference()
 
 bool QgsGeoreferencerMainWindow::georeferenceRaster()
 {
-
   QgsImageWarperTask *task = new QgsImageWarperTask(
     mFileName,
     mModifiedFileName,
@@ -1564,16 +1529,15 @@ bool QgsGeoreferencerMainWindow::georeferenceRaster()
     mCompressionMethod,
     mTargetCrs,
     mUserResX,
-    mUserResY );
+    mUserResY
+  );
 
-  std::unique_ptr< QProgressDialog > progressDialog = std::make_unique< QProgressDialog >( tr( "Georeferencing layer…" ), tr( "Abort" ), 0, 100, this );
+  std::unique_ptr<QProgressDialog> progressDialog = std::make_unique<QProgressDialog>( tr( "Georeferencing layer…" ), tr( "Abort" ), 0, 100, this );
   progressDialog->setWindowTitle( tr( "Georeferencer" ) );
-  connect( task, &QgsTask::progressChanged, progressDialog.get(), [ & ]( double progress )
-  {
-    progressDialog->setValue( static_cast< int >( progress ) );
+  connect( task, &QgsTask::progressChanged, progressDialog.get(), [&]( double progress ) {
+    progressDialog->setValue( static_cast<int>( progress ) );
   } );
-  connect( progressDialog.get(), &QProgressDialog::canceled, task, [ & ]
-  {
+  connect( progressDialog.get(), &QProgressDialog::canceled, task, [&] {
     task->cancel();
   } );
   progressDialog->show();
@@ -1582,15 +1546,13 @@ bool QgsGeoreferencerMainWindow::georeferenceRaster()
   // for illustrating that the task is running in the main window otherwise, so stick with the dialog for now
   QEventLoop loop;
   bool result = true;
-  connect( task, &QgsTask::taskCompleted, &loop, [&loop, this]
-  {
+  connect( task, &QgsTask::taskCompleted, &loop, [&loop, this] {
     postProcessGeoreferencedLayer( mCreateWorldFileOnly ? mFileName : mModifiedFileName, Qgis::LayerType::Raster, QStringLiteral( "gdal" ) );
 
     loop.quit();
   } );
 
-  connect( task, &QgsTask::taskTerminated, &loop, [&loop, this, task, &result]
-  {
+  connect( task, &QgsTask::taskTerminated, &loop, [&loop, this, task, &result] {
     switch ( task->result() )
     {
       case QgsImageWarper::Result::Success:
@@ -1628,17 +1590,14 @@ bool QgsGeoreferencerMainWindow::georeferenceRaster()
 
 bool QgsGeoreferencerMainWindow::georeferenceVector()
 {
-  QgsVectorWarperTask *task = new QgsVectorWarperTask( mTransformMethod,
-      mPoints.asPoints(), mTargetCrs, qobject_cast< QgsVectorLayer * >( mLayer.get() ), mModifiedFileName );
+  QgsVectorWarperTask *task = new QgsVectorWarperTask( mTransformMethod, mPoints.asPoints(), mTargetCrs, qobject_cast<QgsVectorLayer *>( mLayer.get() ), mModifiedFileName );
 
-  std::unique_ptr< QProgressDialog > progressDialog = std::make_unique< QProgressDialog >( tr( "Georeferencing layer…" ), tr( "Abort" ), 0, 100, this );
+  std::unique_ptr<QProgressDialog> progressDialog = std::make_unique<QProgressDialog>( tr( "Georeferencing layer…" ), tr( "Abort" ), 0, 100, this );
   progressDialog->setWindowTitle( tr( "Georeferencer" ) );
-  connect( task, &QgsTask::progressChanged, progressDialog.get(), [ & ]( double progress )
-  {
-    progressDialog->setValue( static_cast< int >( progress ) );
+  connect( task, &QgsTask::progressChanged, progressDialog.get(), [&]( double progress ) {
+    progressDialog->setValue( static_cast<int>( progress ) );
   } );
-  connect( progressDialog.get(), &QProgressDialog::canceled, task, [ & ]
-  {
+  connect( progressDialog.get(), &QProgressDialog::canceled, task, [&] {
     task->cancel();
   } );
   progressDialog->show();
@@ -1647,14 +1606,12 @@ bool QgsGeoreferencerMainWindow::georeferenceVector()
   // for illustrating that the task is running in the main window otherwise, so stick with the dialog for now
   QEventLoop loop;
   bool result = true;
-  connect( task, &QgsTask::taskCompleted, &loop, [&loop, this]
-  {
+  connect( task, &QgsTask::taskCompleted, &loop, [&loop, this] {
     postProcessGeoreferencedLayer( mModifiedFileName, Qgis::LayerType::Vector, QStringLiteral( "ogr" ) );
     loop.quit();
   } );
 
-  connect( task, &QgsTask::taskTerminated, &loop, [&loop, this, task, &result]
-  {
+  connect( task, &QgsTask::taskTerminated, &loop, [&loop, this, task, &result] {
     if ( task->result() != QgsVectorWarperTask::Result::Canceled )
     {
       mMessageBar->pushMessage( tr( "Transform Failed" ), task->errorMessage(), Qgis::MessageLevel::Critical );
@@ -1811,7 +1768,7 @@ bool QgsGeoreferencerMainWindow::writePDFMapFile( const QString &fileName, const
 
   //create layout
   QgsLayout layout( QgsProject::instance() );
-  std::unique_ptr< QgsLayoutItemPage > page = std::make_unique< QgsLayoutItemPage >( &layout );
+  std::unique_ptr<QgsLayoutItemPage> page = std::make_unique<QgsLayoutItemPage>( &layout );
 
   double leftMargin = 8;
   double topMargin = 8;
@@ -1878,10 +1835,10 @@ bool QgsGeoreferencerMainWindow::writePDFReportFile( const QString &fileName, co
   //create layout A4 with 300 dpi
   QgsLayout layout( QgsProject::instance() );
 
-  std::unique_ptr< QgsLayoutItemPage > page = std::make_unique< QgsLayoutItemPage >( &layout );
+  std::unique_ptr<QgsLayoutItemPage> page = std::make_unique<QgsLayoutItemPage>( &layout );
   page->setPageSize( QgsLayoutSize( 210, 297 ) ); //A4
   layout.pageCollection()->addPage( page.release() );
-  std::unique_ptr< QgsLayoutItemPage > page2 = std::make_unique< QgsLayoutItemPage >( &layout );
+  std::unique_ptr<QgsLayoutItemPage> page2 = std::make_unique<QgsLayoutItemPage>( &layout );
   page2->setPageSize( QgsLayoutSize( 210, 297 ) ); //A4
   layout.pageCollection()->addPage( page2.release() );
 
@@ -2056,12 +2013,12 @@ bool QgsGeoreferencerMainWindow::writePDFReportFile( const QString &fileName, co
   gcpTable->setColumns( gcpTableColumns );
 
   QgsGCPList::const_iterator gcpIt = mPoints.constBegin();
-  QVector< QStringList > gcpTableContents;
+  QVector<QStringList> gcpTableContents;
   for ( ; gcpIt != mPoints.constEnd(); ++gcpIt )
   {
     QStringList currentGCPStrings;
     QPointF residual = ( *gcpIt )->residual();
-    double residualTot = std::sqrt( residual.x() * residual.x() +  residual.y() * residual.y() );
+    double residualTot = std::sqrt( residual.x() * residual.x() + residual.y() * residual.y() );
 
     currentGCPStrings << QString::number( ( *gcpIt )->id() );
     if ( ( *gcpIt )->isEnabled() )
@@ -2076,7 +2033,7 @@ bool QgsGeoreferencerMainWindow::writePDFReportFile( const QString &fileName, co
     const QgsPointXY transformedDestinationPoint = ( *gcpIt )->transformedDestinationPoint( mTargetCrs, QgsProject::instance()->transformContext() );
 
     currentGCPStrings << QString::number( ( *gcpIt )->sourcePoint().x(), 'f', 0 ) << QString::number( ( *gcpIt )->sourcePoint().y(), 'f', 0 ) << QString::number( transformedDestinationPoint.x(), 'f', 3 )
-                      <<  QString::number( transformedDestinationPoint.y(), 'f', 3 ) <<  QString::number( residual.x() ) <<  QString::number( residual.y() ) << QString::number( residualTot );
+                      << QString::number( transformedDestinationPoint.y(), 'f', 3 ) << QString::number( residual.x() ) << QString::number( residual.y() ) << QString::number( residualTot );
     gcpTableContents << currentGCPStrings;
   }
 
@@ -2143,8 +2100,7 @@ void QgsGeoreferencerMainWindow::showGDALScript( const QStringList &commands )
 
   // create window to show gdal script
   QDialogButtonBox *bbxGdalScript = new QDialogButtonBox( QDialogButtonBox::Cancel, Qt::Horizontal, this );
-  QPushButton *pbnCopyInClipBoard = new QPushButton( QgsApplication::getThemeIcon( QStringLiteral( "/mActionEditPaste.svg" ) ),
-      tr( "Copy to Clipboard" ), bbxGdalScript );
+  QPushButton *pbnCopyInClipBoard = new QPushButton( QgsApplication::getThemeIcon( QStringLiteral( "/mActionEditPaste.svg" ) ), tr( "Copy to Clipboard" ), bbxGdalScript );
   bbxGdalScript->addButton( pbnCopyInClipBoard, QDialogButtonBox::AcceptRole );
 
   QPlainTextEdit *pteScript = new QPlainTextEdit();
@@ -2184,11 +2140,7 @@ QString QgsGeoreferencerMainWindow::generateGDALtranslateCommand( bool generateT
   {
     const QgsPointXY pixel = mGeorefTransform.toSourcePixel( pt->sourcePoint() );
     const QgsPointXY transformedDestinationPoint = pt->transformedDestinationPoint( mTargetCrs, QgsProject::instance()->transformContext() );
-    gdalCommand << QStringLiteral( "-gcp %1 %2 %3 %4" ).arg(
-                  qgsDoubleToString( pixel.x(), 3 ),
-                  qgsDoubleToString( -pixel.y(), 3 ),
-                  qgsDoubleToString( transformedDestinationPoint.x(), precision ),
-                  qgsDoubleToString( transformedDestinationPoint.y(), precision ) );
+    gdalCommand << QStringLiteral( "-gcp %1 %2 %3 %4" ).arg( qgsDoubleToString( pixel.x(), 3 ), qgsDoubleToString( -pixel.y(), 3 ), qgsDoubleToString( transformedDestinationPoint.x(), precision ), qgsDoubleToString( transformedDestinationPoint.y(), precision ) );
   }
 
   QFileInfo rasterFileInfo( mFileName );
@@ -2209,11 +2161,7 @@ QString QgsGeoreferencerMainWindow::generateGDALogr2ogrCommand() const
   for ( QgsGeorefDataPoint *pt : std::as_const( mPoints ) )
   {
     const QgsPointXY dest = pt->transformedDestinationPoint( mTargetCrs, QgsProject::instance()->transformContext() );
-    gdalCommand << QStringLiteral( "-gcp %1 %2 %3 %4" ).arg(
-                  qgsDoubleToString( pt->sourcePoint().x(), sourcePrecision ),
-                  qgsDoubleToString( pt->sourcePoint().y(), sourcePrecision ),
-                  qgsDoubleToString( dest.x(), destPrecision ),
-                  qgsDoubleToString( dest.y(), destPrecision ) );
+    gdalCommand << QStringLiteral( "-gcp %1 %2 %3 %4" ).arg( qgsDoubleToString( pt->sourcePoint().x(), sourcePrecision ), qgsDoubleToString( pt->sourcePoint().y(), sourcePrecision ), qgsDoubleToString( dest.x(), destPrecision ), qgsDoubleToString( dest.y(), destPrecision ) );
   }
 
   switch ( mTransformMethod )
@@ -2248,8 +2196,7 @@ QString QgsGeoreferencerMainWindow::generateGDALogr2ogrCommand() const
   return gdalCommand.join( QLatin1Char( ' ' ) );
 }
 
-QString QgsGeoreferencerMainWindow::generateGDALwarpCommand( const QString &resampling, const QString &compress,
-    bool useZeroForTrans, int order, double targetResX, double targetResY )
+QString QgsGeoreferencerMainWindow::generateGDALwarpCommand( const QString &resampling, const QString &compress, bool useZeroForTrans, int order, double targetResX, double targetResY )
 {
   QStringList gdalCommand;
   gdalCommand << QStringLiteral( "gdalwarp" ) << QStringLiteral( "-r" ) << resampling;
@@ -2300,8 +2247,7 @@ bool QgsGeoreferencerMainWindow::validate()
     return false;
   }
 
-  if ( mModifiedFileName.isEmpty() && ( !mCreateWorldFileOnly
-                                        || ( QgsGcpTransformerInterface::TransformMethod::Linear != mTransformMethod && QgsGcpTransformerInterface::TransformMethod::Helmert != mTransformMethod ) ) )
+  if ( mModifiedFileName.isEmpty() && ( !mCreateWorldFileOnly || ( QgsGcpTransformerInterface::TransformMethod::Linear != mTransformMethod && QgsGcpTransformerInterface::TransformMethod::Helmert != mTransformMethod ) ) )
   {
     QMessageBox::information( this, tr( "Georeferencer" ), tr( "Please set output file name." ) );
     showTransformSettingsDialog();
@@ -2310,9 +2256,7 @@ bool QgsGeoreferencerMainWindow::validate()
 
   if ( mPoints.count() < static_cast<int>( mGeorefTransform.minimumGcpCount() ) )
   {
-    mMessageBar->pushMessage( tr( "Not Enough GCPs" ), tr( "%1 transformation requires at least %n GCPs. Please define more.", nullptr, mGeorefTransform.minimumGcpCount() )
-                              .arg( QgsGcpTransformerInterface::methodToString( mTransformMethod ) )
-                              , Qgis::MessageLevel::Critical );
+    mMessageBar->pushMessage( tr( "Not Enough GCPs" ), tr( "%1 transformation requires at least %n GCPs. Please define more.", nullptr, mGeorefTransform.minimumGcpCount() ).arg( QgsGcpTransformerInterface::methodToString( mTransformMethod ) ), Qgis::MessageLevel::Critical );
     return false;
   }
 
@@ -2348,9 +2292,7 @@ bool QgsGeoreferencerMainWindow::updateGeorefTransform()
 
 // Samples the given rectangle at numSamples per edge.
 // Returns an axis aligned bounding box which contains the transformed samples.
-QgsRectangle QgsGeoreferencerMainWindow::transformViewportBoundingBox( const QgsRectangle &canvasExtent,
-    QgsGeorefTransform &t,
-    bool rasterToWorld, uint numSamples )
+QgsRectangle QgsGeoreferencerMainWindow::transformViewportBoundingBox( const QgsRectangle &canvasExtent, QgsGeorefTransform &t, bool rasterToWorld, uint numSamples )
 {
   double minX, minY;
   double maxX, maxY;
@@ -2363,7 +2305,7 @@ QgsRectangle QgsGeoreferencerMainWindow::transformViewportBoundingBox( const Qgs
   double dY = canvasExtent.yMaximum();
   double stepX = numSamples ? ( dX - oX ) / ( numSamples - 1 ) : 0.0;
   double stepY = numSamples ? ( dY - oY ) / ( numSamples - 1 ) : 0.0;
-  for ( uint s = 0u;  s < numSamples; s++ )
+  for ( uint s = 0u; s < numSamples; s++ )
   {
     for ( uint edge = 0; edge < 4; edge++ )
     {
@@ -2445,9 +2387,7 @@ bool QgsGeoreferencerMainWindow::checkFileExisting( const QString &fileName, con
   {
     if ( QFile::exists( fileName ) )
     {
-      int r = QMessageBox::question( this, title, question,
-                                     QMessageBox::Yes | QMessageBox::Default,
-                                     QMessageBox::No | QMessageBox::Escape );
+      int r = QMessageBox::question( this, title, question, QMessageBox::Yes | QMessageBox::Default, QMessageBox::No | QMessageBox::Escape );
       if ( r == QMessageBox::No )
         return false;
       else
@@ -2458,7 +2398,7 @@ bool QgsGeoreferencerMainWindow::checkFileExisting( const QString &fileName, con
   return true;
 }
 
-bool QgsGeoreferencerMainWindow::equalGCPlists( const QList< QgsGcpPoint > &list1, const QgsGCPList &list2 )
+bool QgsGeoreferencerMainWindow::equalGCPlists( const QList<QgsGcpPoint> &list1, const QgsGCPList &list2 )
 {
   if ( list1.count() != list2.count() )
     return false;
