@@ -15,6 +15,7 @@
  *                                                                         *
  ***************************************************************************/
 #include "qgscustomization.h"
+#include "moc_qgscustomization.cpp"
 #include "qgisapp.h"
 #include "qgsapplication.h"
 #include "qgslogger.h"
@@ -54,9 +55,9 @@ bool isInternalWidget( const QString &name )
 
 #ifdef Q_OS_MACOS
 QgsCustomizationDialog::QgsCustomizationDialog( QWidget *parent, QSettings *settings )
-  : QMainWindow( parent, Qt::WindowSystemMenuHint )  // Modeless dialog with close button only
+  : QMainWindow( parent, Qt::WindowSystemMenuHint ) // Modeless dialog with close button only
 #else
-QgsCustomizationDialog::QgsCustomizationDialog( QWidget * parent, QSettings * settings )
+QgsCustomizationDialog::QgsCustomizationDialog( QWidget *parent, QSettings *settings )
   : QMainWindow( parent )
 #endif
 {
@@ -79,14 +80,13 @@ QgsCustomizationDialog::QgsCustomizationDialog( QWidget * parent, QSettings * se
   myHeaders << tr( "Object name" ) << tr( "Label" );
   treeWidget->setHeaderLabels( myHeaders );
 
-  mLastDirSettingsName  = QStringLiteral( "/UI/lastCustomizationDir" );
+  mLastDirSettingsName = QStringLiteral( "/UI/lastCustomizationDir" );
   //treeWidget->hideColumn(0)
   connect( buttonBox->button( QDialogButtonBox::Ok ), &QAbstractButton::clicked, this, &QgsCustomizationDialog::ok );
   connect( buttonBox->button( QDialogButtonBox::Apply ), &QAbstractButton::clicked, this, &QgsCustomizationDialog::apply );
   connect( buttonBox->button( QDialogButtonBox::Cancel ), &QAbstractButton::clicked, this, &QgsCustomizationDialog::cancel );
   connect( buttonBox->button( QDialogButtonBox::Reset ), &QAbstractButton::clicked, this, &QgsCustomizationDialog::reset );
   connect( buttonBox->button( QDialogButtonBox::Help ), &QAbstractButton::clicked, this, &QgsCustomizationDialog::showHelp );
-
 }
 
 QTreeWidgetItem *QgsCustomizationDialog::item( const QString &path, QTreeWidgetItem *widgetItem )
@@ -97,7 +97,7 @@ QTreeWidgetItem *QgsCustomizationDialog::item( const QString &path, QTreeWidgetI
   QStringList names = pathCopy.split( '/' );
   pathCopy = QStringList( names.mid( 1 ) ).join( QLatin1Char( '/' ) );
 
-  if ( ! widgetItem )
+  if ( !widgetItem )
   {
     for ( int i = 0; i < treeWidget->topLevelItemCount(); ++i )
     {
@@ -138,9 +138,8 @@ bool QgsCustomizationDialog::filterItems( const QString &text )
 
   mTreeInitialVisible.clear();
   // initially hide everything
-  std::function< void( QTreeWidgetItem *, bool ) > setChildrenVisible;
-  setChildrenVisible = [this, &setChildrenVisible]( QTreeWidgetItem * item, bool visible )
-  {
+  std::function<void( QTreeWidgetItem *, bool )> setChildrenVisible;
+  setChildrenVisible = [this, &setChildrenVisible]( QTreeWidgetItem *item, bool visible ) {
     for ( int i = 0; i < item->childCount(); ++i )
       setChildrenVisible( item->child( i ), visible );
     mTreeInitialVisible.insert( item, !item->isHidden() );
@@ -210,7 +209,6 @@ void QgsCustomizationDialog::settingsToItem( const QString &path, QTreeWidgetIte
 
 void QgsCustomizationDialog::itemToSettings( const QString &path, QTreeWidgetItem *item, QSettings *settings )
 {
-
   QString objectName = item->text( 0 );
   if ( objectName.isEmpty() )
     return; // object is not identifiable
@@ -283,9 +281,7 @@ void QgsCustomizationDialog::actionSave_triggered( bool checked )
   QSettings mySettings;
   QString lastDir = mySettings.value( mLastDirSettingsName, QDir::homePath() ).toString();
 
-  QString fileName = QFileDialog::getSaveFileName( this,
-                     tr( "Choose a customization INI file" ),
-                     lastDir, tr( "Customization files (*.ini)" ) );
+  QString fileName = QFileDialog::getSaveFileName( this, tr( "Choose a customization INI file" ), lastDir, tr( "Customization files (*.ini)" ) );
 
   if ( fileName.isEmpty() )
   {
@@ -310,9 +306,7 @@ void QgsCustomizationDialog::actionLoad_triggered( bool checked )
   QSettings mySettings;
   QString lastDir = mySettings.value( mLastDirSettingsName, QDir::homePath() ).toString();
 
-  QString fileName = QFileDialog::getOpenFileName( this,
-                     tr( "Choose a customization INI file" ),
-                     lastDir, tr( "Customization files (*.ini)" ) );
+  QString fileName = QFileDialog::getOpenFileName( this, tr( "Choose a customization INI file" ), lastDir, tr( "Customization files (*.ini)" ) );
 
   if ( fileName.isEmpty() )
     return;
@@ -376,9 +370,8 @@ void QgsCustomizationDialog::init()
 
 QTreeWidgetItem *QgsCustomizationDialog::createTreeItemWidgets()
 {
-
   QDomDocument myDoc( QStringLiteral( "QgsWidgets" ) );
-  QFile myFile( QgsApplication::pkgDataPath() +  "/resources/customization.xml" );
+  QFile myFile( QgsApplication::pkgDataPath() + "/resources/customization.xml" );
   if ( !myFile.open( QIODevice::ReadOnly ) )
   {
     return nullptr;
@@ -730,11 +723,11 @@ void QgsCustomization::createTreeItemBrowser()
   mBrowserItem = new QTreeWidgetItem( data );
   QVector<QStringList> items;
 
-  items << QStringList( {QStringLiteral( "special:Home" ), tr( "Home Folder" )} );
-  items << QStringList( {QStringLiteral( "special:ProjectHome" ), tr( "Project Home Folder" )} );
-  items << QStringList( {QStringLiteral( "special:Favorites" ), tr( "Favorites Folder" )} );
-  items << QStringList( {QStringLiteral( "special:Drives" ), tr( "Drive Folders (e.g. C:\\)" )} );
-  items << QStringList( {QStringLiteral( "special:Volumes" ), tr( "Volume Folder (MacOS only)" )} );
+  items << QStringList( { QStringLiteral( "special:Home" ), tr( "Home Folder" ) } );
+  items << QStringList( { QStringLiteral( "special:ProjectHome" ), tr( "Project Home Folder" ) } );
+  items << QStringList( { QStringLiteral( "special:Favorites" ), tr( "Favorites Folder" ) } );
+  items << QStringList( { QStringLiteral( "special:Drives" ), tr( "Drive Folders (e.g. C:\\)" ) } );
+  items << QStringList( { QStringLiteral( "special:Volumes" ), tr( "Volume Folder (MacOS only)" ) } );
 
   const auto constProviders = QgsApplication::dataItemProviderRegistry()->providers();
   for ( QgsDataItemProvider *pr : constProviders )
@@ -769,7 +762,6 @@ QgsCustomization *QgsCustomization::instance()
 QgsCustomization::QgsCustomization()
   : mStatusPath( QStringLiteral( "/Customization/status" ) )
 {
-
   QSettings settings;
   mEnabled = settings.value( QStringLiteral( "UI/Customization/enabled" ), "false" ).toString() == QLatin1String( "true" );
 }
@@ -1129,8 +1121,8 @@ void QgsCustomization::loadDefault()
     return;
 
   // Look for default
-  QString path = QgsApplication::pkgDataPath() +  "/resources/customization.ini";
-  if ( ! QFile::exists( path ) )
+  QString path = QgsApplication::pkgDataPath() + "/resources/customization.ini";
+  if ( !QFile::exists( path ) )
   {
     QgsDebugMsgLevel( "Default customization not found in " + path, 2 );
     return;
