@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgsmergeattributesdialog.h"
+#include "moc_qgsmergeattributesdialog.cpp"
 #include "qgsapplication.h"
 #include "qgsfeatureiterator.h"
 #include "qgsfields.h"
@@ -33,22 +34,21 @@
 #include <limits>
 #include <QComboBox>
 
-const QList< Qgis::Statistic > QgsMergeAttributesDialog::DISPLAY_STATS =
-  QList< Qgis::Statistic > () << Qgis::Statistic::Count
-  << Qgis::Statistic::Sum
-  << Qgis::Statistic::Mean
-  << Qgis::Statistic::Median
-  << Qgis::Statistic::StDev
-  << Qgis::Statistic::StDevSample
-  << Qgis::Statistic::Min
-  << Qgis::Statistic::Max
-  << Qgis::Statistic::Range
-  << Qgis::Statistic::Minority
-  << Qgis::Statistic::Majority
-  << Qgis::Statistic::Variety
-  << Qgis::Statistic::FirstQuartile
-  << Qgis::Statistic::ThirdQuartile
-  << Qgis::Statistic::InterQuartileRange;
+const QList<Qgis::Statistic> QgsMergeAttributesDialog::DISPLAY_STATS = QList<Qgis::Statistic>() << Qgis::Statistic::Count
+                                                                                                << Qgis::Statistic::Sum
+                                                                                                << Qgis::Statistic::Mean
+                                                                                                << Qgis::Statistic::Median
+                                                                                                << Qgis::Statistic::StDev
+                                                                                                << Qgis::Statistic::StDevSample
+                                                                                                << Qgis::Statistic::Min
+                                                                                                << Qgis::Statistic::Max
+                                                                                                << Qgis::Statistic::Range
+                                                                                                << Qgis::Statistic::Minority
+                                                                                                << Qgis::Statistic::Majority
+                                                                                                << Qgis::Statistic::Variety
+                                                                                                << Qgis::Statistic::FirstQuartile
+                                                                                                << Qgis::Statistic::ThirdQuartile
+                                                                                                << Qgis::Statistic::InterQuartileRange;
 
 QgsMergeAttributesDialog::QgsMergeAttributesDialog( const QgsFeatureList &features, QgsVectorLayer *vl, QgsMapCanvas *canvas, QWidget *parent, Qt::WindowFlags f )
   : QDialog( parent, f )
@@ -128,7 +128,7 @@ QgsMergeAttributesDialog::~QgsMergeAttributesDialog()
 
 void QgsMergeAttributesDialog::setAttributeTableConfig( const QgsAttributeTableConfig &config )
 {
-  const QVector< QgsAttributeTableConfig::ColumnConfig > columns = config.columns();
+  const QVector<QgsAttributeTableConfig::ColumnConfig> columns = config.columns();
   for ( const QgsAttributeTableConfig::ColumnConfig &columnConfig : columns )
   {
     if ( columnConfig.hidden )
@@ -178,15 +178,14 @@ void QgsMergeAttributesDialog::createTableWidgetContents()
     }
 
     mTableWidget->setColumnCount( col + 1 );
-    mFieldToColumnMap[ mFields.at( idx ).name() ] = col;
+    mFieldToColumnMap[mFields.at( idx ).name()] = col;
 
     QTableWidgetItem *item = new QTableWidgetItem( mFields.at( idx ).name() );
     item->setData( FieldIndex, idx );
     mTableWidget->setHorizontalHeaderItem( col, item );
 
     QComboBox *cb = createMergeComboBox( mFields.at( idx ).type(), col );
-    if ( ( ! mVectorLayer->dataProvider()->pkAttributeIndexes().contains( mFields.fieldOriginIndex( idx ) ) &&
-           mFields.at( idx ).constraints().constraints() & QgsFieldConstraints::ConstraintUnique ) || mHiddenAttributes.contains( idx ) )
+    if ( ( !mVectorLayer->dataProvider()->pkAttributeIndexes().contains( mFields.fieldOriginIndex( idx ) ) && mFields.at( idx ).constraints().constraints() & QgsFieldConstraints::ConstraintUnique ) || mHiddenAttributes.contains( idx ) )
     {
       cb->setCurrentIndex( cb->findData( "skip" ) );
     }
@@ -296,7 +295,7 @@ QComboBox *QgsMergeAttributesDialog::createMergeComboBox( QMetaType::Type column
     {
       for ( Qgis::Statistic stat : std::as_const( DISPLAY_STATS ) )
       {
-        newComboBox->addItem( QgsStatisticalSummary::displayName( stat ), static_cast< int >( stat ) );
+        newComboBox->addItem( QgsStatisticalSummary::displayName( stat ), static_cast<int>( stat ) );
       }
       break;
     }
@@ -312,8 +311,7 @@ QComboBox *QgsMergeAttributesDialog::createMergeComboBox( QMetaType::Type column
   newComboBox->addItem( tr( "Skip Attribute" ), QStringLiteral( "skip" ) );
   newComboBox->addItem( tr( "Manual Value" ), QStringLiteral( "manual" ) );
 
-  connect( newComboBox, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, [ = ]()
-  {
+  connect( newComboBox, static_cast<void ( QComboBox::* )( int )>( &QComboBox::currentIndexChanged ), this, [=]() {
     bool isManual = newComboBox->currentData() == QLatin1String( "manual" );
     updateManualWidget( column, isManual );
     refreshMergedValue( column );
@@ -410,7 +408,7 @@ void QgsMergeAttributesDialog::refreshMergedValue( int col )
     else
     {
       //numerical statistic
-      Qgis::Statistic stat = static_cast< Qgis::Statistic >( comboBox->currentData().toInt() );
+      Qgis::Statistic stat = static_cast<Qgis::Statistic>( comboBox->currentData().toInt() );
       mergeResult = calcStatistic( fieldIdx, stat );
     }
 
@@ -419,7 +417,7 @@ void QgsMergeAttributesDialog::refreshMergedValue( int col )
 
     // Result formatting
     QString stringVal;
-    if ( mergeBehaviorString != QLatin1String( "skip" ) &&  mergeBehaviorString != QLatin1String( "manual" ) )
+    if ( mergeBehaviorString != QLatin1String( "skip" ) && mergeBehaviorString != QLatin1String( "manual" ) )
     {
       const QgsEditorWidgetSetup setup = mFields.at( fieldIdx ).editorWidgetSetup();
       const QgsFieldFormatter *formatter = QgsApplication::fieldFormatterRegistry()->fieldFormatter( setup.type() );
@@ -460,8 +458,7 @@ void QgsMergeAttributesDialog::setAllAttributesFromFeature( QgsFeatureId feature
     if ( !currentComboBox )
       continue;
 
-    if ( ! mVectorLayer->dataProvider()->pkAttributeIndexes().contains( mVectorLayer->fields().fieldOriginIndex( i ) ) &&
-         mVectorLayer->fields().at( i ).constraints().constraints() & QgsFieldConstraints::ConstraintUnique )
+    if ( !mVectorLayer->dataProvider()->pkAttributeIndexes().contains( mVectorLayer->fields().fieldOriginIndex( i ) ) && mVectorLayer->fields().at( i ).constraints().constraints() & QgsFieldConstraints::ConstraintUnique )
     {
       currentComboBox->setCurrentIndex( currentComboBox->findData( QStringLiteral( "skip" ) ) );
     }
