@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgssensorthingssourcewidget.h"
+#include "moc_qgssensorthingssourcewidget.cpp"
 ///@cond PRIVATE
 
 #include "qgsproviderregistry.h"
@@ -67,8 +68,7 @@ QgsSensorThingsSourceWidget::QgsSensorThingsSourceWidget( QWidget *parent )
   QgsSensorThingsRemoveExpansionDelegate *removeDelegate = new QgsSensorThingsRemoveExpansionDelegate( mExpansionsTable );
   mExpansionsTable->setItemDelegateForColumn( QgsSensorThingsExpansionsModel::Column::Actions, removeDelegate );
   mExpansionsTable->viewport()->installEventFilter( removeDelegate );
-  connect( mExpansionsTable, &QTableView::clicked, this, [this]( const QModelIndex & index )
-  {
+  connect( mExpansionsTable, &QTableView::clicked, this, [this]( const QModelIndex &index ) {
     if ( index.column() == QgsSensorThingsExpansionsModel::Column::Actions )
     {
       mExpansionsModel->removeRows( index.row(), 1 );
@@ -104,9 +104,9 @@ QgsSensorThingsSourceWidget::QgsSensorThingsSourceWidget( QWidget *parent )
 
   setCurrentEntityType( Qgis::SensorThingsEntity::Location );
 
-  connect( mComboEntityType, qOverload< int >( &QComboBox::currentIndexChanged ), this, &QgsSensorThingsSourceWidget::entityTypeChanged );
-  connect( mComboGeometryType, qOverload< int >( &QComboBox::currentIndexChanged ), this, &QgsSensorThingsSourceWidget::validate );
-  connect( mSpinPageSize, qOverload< int >( &QSpinBox::valueChanged ), this, &QgsSensorThingsSourceWidget::validate );
+  connect( mComboEntityType, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsSensorThingsSourceWidget::entityTypeChanged );
+  connect( mComboGeometryType, qOverload<int>( &QComboBox::currentIndexChanged ), this, &QgsSensorThingsSourceWidget::validate );
+  connect( mSpinPageSize, qOverload<int>( &QSpinBox::valueChanged ), this, &QgsSensorThingsSourceWidget::validate );
   connect( mRetrieveTypesButton, &QToolButton::clicked, this, &QgsSensorThingsSourceWidget::retrieveTypes );
   mRetrieveTypesButton->setEnabled( false );
   connect( mExtentWidget, &QgsExtentWidget::extentChanged, this, &QgsSensorThingsSourceWidget::validate );
@@ -127,15 +127,15 @@ QgsSensorThingsSourceWidget::~QgsSensorThingsSourceWidget()
 void QgsSensorThingsSourceWidget::setSourceUri( const QString &uri )
 {
   mSourceParts = QgsProviderRegistry::instance()->decodeUri(
-                   QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
-                   uri
-                 );
+    QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
+    uri
+  );
 
   const Qgis::SensorThingsEntity type = QgsSensorThingsUtils::stringToEntity( mSourceParts.value( QStringLiteral( "entity" ) ).toString() );
   if ( type != Qgis::SensorThingsEntity::Invalid )
     mComboEntityType->setCurrentIndex( mComboEntityType->findData( QVariant::fromValue( type ) ) );
 
-  setCurrentEntityType( mComboEntityType->currentData().value< Qgis::SensorThingsEntity >() );
+  setCurrentEntityType( mComboEntityType->currentData().value<Qgis::SensorThingsEntity>() );
   setCurrentGeometryTypeFromString( mSourceParts.value( QStringLiteral( "geometryType" ) ).toString() );
 
   bool ok = false;
@@ -162,7 +162,7 @@ void QgsSensorThingsSourceWidget::setSourceUri( const QString &uri )
     mSpinFeatureLimit->setValue( QgsSensorThingsUtils::DEFAULT_FEATURE_LIMIT );
   }
 
-  const QgsRectangle bounds = mSourceParts.value( QStringLiteral( "bounds" ) ).value< QgsRectangle >();
+  const QgsRectangle bounds = mSourceParts.value( QStringLiteral( "bounds" ) ).value<QgsRectangle>();
   if ( !bounds.isNull() )
   {
     mExtentWidget->setCurrentExtent( bounds, QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:4326" ) ) );
@@ -174,11 +174,11 @@ void QgsSensorThingsSourceWidget::setSourceUri( const QString &uri )
   }
 
   const QVariantList expandTo = mSourceParts.value( QStringLiteral( "expandTo" ) ).toList();
-  QList< QgsSensorThingsExpansionDefinition> expansions;
+  QList<QgsSensorThingsExpansionDefinition> expansions;
   QStringList expansionsLabelText;
   for ( const QVariant &expandVariant : expandTo )
   {
-    const QgsSensorThingsExpansionDefinition definition = expandVariant.value< QgsSensorThingsExpansionDefinition >();
+    const QgsSensorThingsExpansionDefinition definition = expandVariant.value<QgsSensorThingsExpansionDefinition>();
     if ( definition.isValid() )
     {
       expansions.append( definition );
@@ -193,9 +193,9 @@ void QgsSensorThingsSourceWidget::setSourceUri( const QString &uri )
 QString QgsSensorThingsSourceWidget::sourceUri() const
 {
   return updateUriFromGui( QgsProviderRegistry::instance()->encodeUri(
-                             QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
-                             mSourceParts
-                           ) );
+    QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
+    mSourceParts
+  ) );
 }
 
 QString QgsSensorThingsSourceWidget::groupTitle() const
@@ -211,17 +211,17 @@ void QgsSensorThingsSourceWidget::setMapCanvas( QgsMapCanvas *mapCanvas )
 
 Qgis::SensorThingsEntity QgsSensorThingsSourceWidget::currentEntityType() const
 {
-  return mComboEntityType->currentData().value< Qgis::SensorThingsEntity >();
+  return mComboEntityType->currentData().value<Qgis::SensorThingsEntity>();
 }
 
 QString QgsSensorThingsSourceWidget::updateUriFromGui( const QString &connectionUri ) const
 {
   QVariantMap parts = QgsProviderRegistry::instance()->decodeUri(
-                        QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
-                        connectionUri
-                      );
+    QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
+    connectionUri
+  );
 
-  const Qgis::SensorThingsEntity entityType = mComboEntityType->currentData().value< Qgis::SensorThingsEntity >();
+  const Qgis::SensorThingsEntity entityType = mComboEntityType->currentData().value<Qgis::SensorThingsEntity>();
   parts.insert( QStringLiteral( "entity" ), qgsEnumValueToKey( entityType ) );
   if ( !QgsSensorThingsUtils::entityTypeHasGeometry( entityType ) )
   {
@@ -229,7 +229,7 @@ QString QgsSensorThingsSourceWidget::updateUriFromGui( const QString &connection
   }
   else
   {
-    const Qgis::WkbType newWkbType = mComboGeometryType->currentData().value< Qgis::WkbType >();
+    const Qgis::WkbType newWkbType = mComboGeometryType->currentData().value<Qgis::WkbType>();
     switch ( newWkbType )
     {
       case Qgis::WkbType::Point:
@@ -270,7 +270,7 @@ QString QgsSensorThingsSourceWidget::updateUriFromGui( const QString &connection
     parts.remove( QStringLiteral( "featureLimit" ) );
   }
 
-  const QList< QgsSensorThingsExpansionDefinition> expansions = mExpansionsModel->expansions();
+  const QList<QgsSensorThingsExpansionDefinition> expansions = mExpansionsModel->expansions();
   if ( expansions.isEmpty() )
   {
     parts.remove( QStringLiteral( "expandTo" ) );
@@ -291,14 +291,14 @@ QString QgsSensorThingsSourceWidget::updateUriFromGui( const QString &connection
     parts.insert( QStringLiteral( "bounds" ), QVariant::fromValue( mExtentWidget->outputExtent() ) );
 
   return QgsProviderRegistry::instance()->encodeUri(
-           QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
-           parts
-         );
+    QgsSensorThingsProvider::SENSORTHINGS_PROVIDER_KEY,
+    parts
+  );
 }
 
 void QgsSensorThingsSourceWidget::entityTypeChanged()
 {
-  const Qgis::SensorThingsEntity entityType = mComboEntityType->currentData().value< Qgis::SensorThingsEntity >();
+  const Qgis::SensorThingsEntity entityType = mComboEntityType->currentData().value<Qgis::SensorThingsEntity>();
   setCurrentEntityType( entityType );
 
   validate();
@@ -308,7 +308,7 @@ void QgsSensorThingsSourceWidget::validate()
 {
   bool valid = mComboEntityType->currentIndex() >= 0;
 
-  const Qgis::SensorThingsEntity entityType = mComboEntityType->currentData().value< Qgis::SensorThingsEntity >();
+  const Qgis::SensorThingsEntity entityType = mComboEntityType->currentData().value<Qgis::SensorThingsEntity>();
   if ( QgsSensorThingsUtils::entityTypeHasGeometry( entityType ) )
     valid = valid && mComboGeometryType->currentIndex() >= 0;
 
@@ -328,8 +328,7 @@ void QgsSensorThingsSourceWidget::retrieveTypes()
     mPropertiesTask = nullptr;
   }
 
-  mPropertiesTask = new QgsSensorThingsConnectionPropertiesTask( mSourceParts.value( QStringLiteral( "url" ) ).toString(),
-      mComboEntityType->currentData().value< Qgis::SensorThingsEntity >() );
+  mPropertiesTask = new QgsSensorThingsConnectionPropertiesTask( mSourceParts.value( QStringLiteral( "url" ) ).toString(), mComboEntityType->currentData().value<Qgis::SensorThingsEntity>() );
   connect( mPropertiesTask, &QgsTask::taskCompleted, this, &QgsSensorThingsSourceWidget::connectionPropertiesTaskCompleted );
   QgsApplication::taskManager()->addTask( mPropertiesTask );
   mRetrieveTypesButton->setEnabled( false );
@@ -337,8 +336,8 @@ void QgsSensorThingsSourceWidget::retrieveTypes()
 
 void QgsSensorThingsSourceWidget::connectionPropertiesTaskCompleted()
 {
-  const QList< Qgis::GeometryType > availableTypes = mPropertiesTask->geometryTypes();
-  const Qgis::WkbType currentWkbType = mComboGeometryType->currentData().value< Qgis::WkbType >();
+  const QList<Qgis::GeometryType> availableTypes = mPropertiesTask->geometryTypes();
+  const Qgis::WkbType currentWkbType = mComboGeometryType->currentData().value<Qgis::WkbType>();
   mComboGeometryType->clear();
 
   if ( availableTypes.contains( Qgis::GeometryType::Point ) )
@@ -372,8 +371,7 @@ void QgsSensorThingsSourceWidget::setCurrentEntityType( Qgis::SensorThingsEntity
     mPropertiesTask = nullptr;
   }
 
-  mRetrieveTypesButton->setEnabled( QgsSensorThingsUtils::geometryTypeForEntity( type ) == Qgis::GeometryType::Unknown
-                                    && !mSourceParts.value( QStringLiteral( "url" ) ).toString().isEmpty() );
+  mRetrieveTypesButton->setEnabled( QgsSensorThingsUtils::geometryTypeForEntity( type ) == Qgis::GeometryType::Unknown && !mSourceParts.value( QStringLiteral( "url" ) ).toString().isEmpty() );
   const Qgis::GeometryType geometryTypeForEntity = QgsSensorThingsUtils::geometryTypeForEntity( type );
   if ( geometryTypeForEntity == Qgis::GeometryType::Unknown && mComboGeometryType->findData( QVariant::fromValue( Qgis::WkbType::Point ) ) < 0 )
   {
@@ -413,7 +411,8 @@ void QgsSensorThingsSourceWidget::setCurrentEntityType( Qgis::SensorThingsEntity
     }
     // we always add a "no geometry" option here, as some services don't correctly respect the mandated geometry types for eg MultiDatastreams
     mComboGeometryType->addItem( QgsIconUtils::iconForWkbType( Qgis::WkbType::NoGeometry ), tr( "No Geometry" ), QVariant::fromValue( Qgis::WkbType::NoGeometry ) );
-    setCurrentGeometryTypeFromString( mSourceParts.value( QStringLiteral( "geometryType" ) ).toString() ); mComboGeometryType->setCurrentIndex( 0 );
+    setCurrentGeometryTypeFromString( mSourceParts.value( QStringLiteral( "geometryType" ) ).toString() );
+    mComboGeometryType->setCurrentIndex( 0 );
   }
 }
 
@@ -452,7 +451,6 @@ void QgsSensorThingsSourceWidget::setCurrentGeometryTypeFromString( const QStrin
 QgsSensorThingsExpansionsModel::QgsSensorThingsExpansionsModel( QObject *parent )
   : QAbstractItemModel( parent )
 {
-
 }
 
 int QgsSensorThingsExpansionsModel::columnCount( const QModelIndex & ) const
@@ -642,14 +640,14 @@ bool QgsSensorThingsExpansionsModel::setData( const QModelIndex &index, const QV
         case Column::Entity:
         {
           const bool wasInvalid = !expansion.isValid();
-          if ( !value.isValid() || value.value< Qgis::SensorThingsEntity >() == Qgis::SensorThingsEntity::Invalid )
+          if ( !value.isValid() || value.value<Qgis::SensorThingsEntity>() == Qgis::SensorThingsEntity::Invalid )
           {
             if ( wasInvalid )
               break;
           }
           else
           {
-            expansion.setChildEntity( value.value< Qgis::SensorThingsEntity >() );
+            expansion.setChildEntity( value.value<Qgis::SensorThingsEntity>() );
             if ( wasInvalid )
             {
               expansion = QgsSensorThingsExpansionDefinition::defaultDefinitionForEntity( expansion.childEntity() );
@@ -694,7 +692,7 @@ bool QgsSensorThingsExpansionsModel::setData( const QModelIndex &index, const QV
 
         case Column::SortOrder:
         {
-          expansion.setSortOrder( value.value< Qt::SortOrder >() );
+          expansion.setSortOrder( value.value<Qt::SortOrder>() );
           emit dataChanged( index, index, QVector<int>() << role );
           break;
         }
@@ -758,7 +756,6 @@ void QgsSensorThingsExpansionsModel::setExpansions( const QList<QgsSensorThingsE
 QgsSensorThingsExpansionsDelegate::QgsSensorThingsExpansionsDelegate( QObject *parent )
   : QStyledItemDelegate( parent )
 {
-
 }
 
 void QgsSensorThingsExpansionsDelegate::setBaseEntityType( Qgis::SensorThingsEntity type )
@@ -774,13 +771,13 @@ QWidget *QgsSensorThingsExpansionsDelegate::createEditor( QWidget *parent, const
     {
       // need to find out entity type for the previous row (or the base entity type for the first row)
       const Qgis::SensorThingsEntity entityType = index.row() == 0 ? mBaseEntityType
-          : index.model()->data( index.model()->index( index.row() - 1, 0 ), Qt::EditRole ).value< Qgis::SensorThingsEntity >();
+                                                                   : index.model()->data( index.model()->index( index.row() - 1, 0 ), Qt::EditRole ).value<Qgis::SensorThingsEntity>();
 
-      QList< Qgis::SensorThingsEntity > compatibleEntities = QgsSensorThingsUtils::expandableTargets( entityType );
+      QList<Qgis::SensorThingsEntity> compatibleEntities = QgsSensorThingsUtils::expandableTargets( entityType );
       // remove all entities which are already part of the expansion in previous rows -- we don't support "circular" expansion
       for ( int row = index.row() - 1; row >= 0; row-- )
       {
-        const Qgis::SensorThingsEntity rowEntityType = index.model()->data( index.model()->index( row, 0 ), Qt::EditRole ).value< Qgis::SensorThingsEntity >();
+        const Qgis::SensorThingsEntity rowEntityType = index.model()->data( index.model()->index( row, 0 ), Qt::EditRole ).value<Qgis::SensorThingsEntity>();
         compatibleEntities.removeAll( rowEntityType );
       }
 
@@ -804,7 +801,7 @@ QWidget *QgsSensorThingsExpansionsDelegate::createEditor( QWidget *parent, const
     case QgsSensorThingsExpansionsModel::Column::OrderBy:
     {
       // need to find out entity type for this row
-      const Qgis::SensorThingsEntity entityType = index.model()->data( index.model()->index( index.row(), 0 ), Qt::EditRole ).value< Qgis::SensorThingsEntity >();
+      const Qgis::SensorThingsEntity entityType = index.model()->data( index.model()->index( index.row(), 0 ), Qt::EditRole ).value<Qgis::SensorThingsEntity>();
       const QStringList availableProperties = QgsSensorThingsUtils::propertiesForEntityType( entityType );
 
       QComboBox *combo = new QComboBox( parent );
@@ -827,14 +824,12 @@ QWidget *QgsSensorThingsExpansionsDelegate::createEditor( QWidget *parent, const
     case QgsSensorThingsExpansionsModel::Column::Filter:
     {
       // need to find out entity type for this row
-      const Qgis::SensorThingsEntity entityType = index.model()->data( index.model()->index( index.row(), 0 ), Qt::EditRole ).value< Qgis::SensorThingsEntity >();
+      const Qgis::SensorThingsEntity entityType = index.model()->data( index.model()->index( index.row(), 0 ), Qt::EditRole ).value<Qgis::SensorThingsEntity>();
       QgsSensorThingsFilterWidget *w = new QgsSensorThingsFilterWidget( parent, entityType );
-      connect( w, &QgsSensorThingsFilterWidget::filterChanged, this, [ = ]()
-      {
-        const_cast< QgsSensorThingsExpansionsDelegate * >( this )->emit commitData( w );
+      connect( w, &QgsSensorThingsFilterWidget::filterChanged, this, [=]() {
+        const_cast<QgsSensorThingsExpansionsDelegate *>( this )->emit commitData( w );
       } );
       return w;
-
     }
 
     default:
@@ -851,7 +846,7 @@ void QgsSensorThingsExpansionsDelegate::setEditorData( QWidget *editor, const QM
     case QgsSensorThingsExpansionsModel::Column::SortOrder:
     case QgsSensorThingsExpansionsModel::Column::OrderBy:
     {
-      if ( QComboBox *combo = qobject_cast< QComboBox * >( editor ) )
+      if ( QComboBox *combo = qobject_cast<QComboBox *>( editor ) )
       {
         combo->setCurrentIndex( combo->findData( index.data( Qt::EditRole ) ) );
         if ( combo->currentIndex() < 0 )
@@ -862,7 +857,7 @@ void QgsSensorThingsExpansionsDelegate::setEditorData( QWidget *editor, const QM
 
     case QgsSensorThingsExpansionsModel::Column::Filter:
     {
-      if ( QgsSensorThingsFilterWidget *w = qobject_cast< QgsSensorThingsFilterWidget * >( editor ) )
+      if ( QgsSensorThingsFilterWidget *w = qobject_cast<QgsSensorThingsFilterWidget *>( editor ) )
       {
         w->setFilter( index.data( Qt::EditRole ).toString() );
       }
@@ -881,7 +876,7 @@ void QgsSensorThingsExpansionsDelegate::setModelData( QWidget *editor, QAbstract
   {
     case QgsSensorThingsExpansionsModel::Column::Entity:
     {
-      if ( QComboBox *combo = qobject_cast< QComboBox * >( editor ) )
+      if ( QComboBox *combo = qobject_cast<QComboBox *>( editor ) )
       {
         model->setData( index, combo->currentData() );
       }
@@ -890,7 +885,7 @@ void QgsSensorThingsExpansionsDelegate::setModelData( QWidget *editor, QAbstract
 
     case QgsSensorThingsExpansionsModel::Column::Limit:
     {
-      if ( QgsSpinBox *spin = qobject_cast< QgsSpinBox * >( editor ) )
+      if ( QgsSpinBox *spin = qobject_cast<QgsSpinBox *>( editor ) )
       {
         model->setData( index, spin->value() );
       }
@@ -899,7 +894,7 @@ void QgsSensorThingsExpansionsDelegate::setModelData( QWidget *editor, QAbstract
 
     case QgsSensorThingsExpansionsModel::Column::OrderBy:
     {
-      if ( QComboBox *combo = qobject_cast< QComboBox * >( editor ) )
+      if ( QComboBox *combo = qobject_cast<QComboBox *>( editor ) )
       {
         model->setData( index, combo->currentData() );
       }
@@ -907,7 +902,7 @@ void QgsSensorThingsExpansionsDelegate::setModelData( QWidget *editor, QAbstract
     }
 
     case QgsSensorThingsExpansionsModel::Column::SortOrder:
-      if ( QComboBox *combo = qobject_cast< QComboBox * >( editor ) )
+      if ( QComboBox *combo = qobject_cast<QComboBox *>( editor ) )
       {
         model->setData( index, combo->currentData() );
       }
@@ -915,7 +910,7 @@ void QgsSensorThingsExpansionsDelegate::setModelData( QWidget *editor, QAbstract
 
     case QgsSensorThingsExpansionsModel::Column::Filter:
     {
-      if ( QgsSensorThingsFilterWidget *w = qobject_cast< QgsSensorThingsFilterWidget * >( editor ) )
+      if ( QgsSensorThingsFilterWidget *w = qobject_cast<QgsSensorThingsFilterWidget *>( editor ) )
       {
         model->setData( index, w->filter() );
       }
@@ -935,7 +930,6 @@ void QgsSensorThingsExpansionsDelegate::setModelData( QWidget *editor, QAbstract
 QgsSensorThingsRemoveExpansionDelegate::QgsSensorThingsRemoveExpansionDelegate( QObject *parent )
   : QStyledItemDelegate( parent )
 {
-
 }
 
 bool QgsSensorThingsRemoveExpansionDelegate::eventFilter( QObject *obj, QEvent *event )
@@ -953,7 +947,7 @@ bool QgsSensorThingsRemoveExpansionDelegate::eventFilter( QObject *obj, QEvent *
   else if ( event->type() == QEvent::HoverLeave )
   {
     setHoveredIndex( QModelIndex() );
-    qobject_cast< QWidget * >( obj )->update();
+    qobject_cast<QWidget *>( obj )->update();
   }
   return QStyledItemDelegate::eventFilter( obj, event );
 }
@@ -972,9 +966,7 @@ void QgsSensorThingsRemoveExpansionDelegate::paint( QPainter *painter, const QSt
   }
 
   const QIcon icon = QgsApplication::getThemeIcon( "/mIconClearItem.svg" );
-  const QRect iconRect( option.rect.left() + ( option.rect.width() - 16 ) / 2,
-                        option.rect.top() + ( option.rect.height() - 16 ) / 2,
-                        16, 16 );
+  const QRect iconRect( option.rect.left() + ( option.rect.width() - 16 ) / 2, option.rect.top() + ( option.rect.height() - 16 ) / 2, 16, 16 );
 
   icon.paint( painter, iconRect );
 }
