@@ -16,6 +16,7 @@
  ***************************************************************************/
 
 #include "qgswmsparameters.h"
+#include "moc_qgswmsparameters.cpp"
 #include "qgsdatasourceuri.h"
 #include "qgsmaplayerserverproperties.h"
 #include "qgsmessagelog.h"
@@ -31,9 +32,7 @@ namespace QgsWms
   //
   // QgsWmsParameter
   //
-  QgsWmsParameter::QgsWmsParameter( const QgsWmsParameter::Name name,
-                                    const QMetaType::Type type,
-                                    const QVariant defaultValue )
+  QgsWmsParameter::QgsWmsParameter( const QgsWmsParameter::Name name, const QMetaType::Type type, const QVariant defaultValue )
     : QgsServerParameterDefinition( type, defaultValue )
     , mName( name )
   {
@@ -222,80 +221,52 @@ namespace QgsWms
     mVersions.append( QgsProjectVersion( 1, 3, 0 ) );
 
     // WMS parameters definition
-    const QgsWmsParameter pQuality( QgsWmsParameter::IMAGE_QUALITY,
-                                    QMetaType::Type::Int,
-                                    QVariant( 0 ) );
+    const QgsWmsParameter pQuality( QgsWmsParameter::IMAGE_QUALITY, QMetaType::Type::Int, QVariant( 0 ) );
     save( pQuality );
 
-    const QgsWmsParameter pTiled( QgsWmsParameter::TILED,
-                                  QMetaType::Type::Bool,
-                                  QVariant( false ) );
+    const QgsWmsParameter pTiled( QgsWmsParameter::TILED, QMetaType::Type::Bool, QVariant( false ) );
     save( pTiled );
 
-    const QgsWmsParameter pBoxSpace( QgsWmsParameter::BOXSPACE,
-                                     QMetaType::Type::Double,
-                                     QVariant( 2.0 ) );
+    const QgsWmsParameter pBoxSpace( QgsWmsParameter::BOXSPACE, QMetaType::Type::Double, QVariant( 2.0 ) );
     save( pBoxSpace );
 
-    const QgsWmsParameter pSymbSpace( QgsWmsParameter::SYMBOLSPACE,
-                                      QMetaType::Type::Double,
-                                      QVariant( 2.0 ) );
+    const QgsWmsParameter pSymbSpace( QgsWmsParameter::SYMBOLSPACE, QMetaType::Type::Double, QVariant( 2.0 ) );
     save( pSymbSpace );
 
-    const QgsWmsParameter pLayerSpace( QgsWmsParameter::LAYERSPACE,
-                                       QMetaType::Type::Double,
-                                       QVariant( 3.0 ) );
+    const QgsWmsParameter pLayerSpace( QgsWmsParameter::LAYERSPACE, QMetaType::Type::Double, QVariant( 3.0 ) );
     save( pLayerSpace );
 
-    const QgsWmsParameter pTitleSpace( QgsWmsParameter::LAYERTITLESPACE,
-                                       QMetaType::Type::Double,
-                                       QVariant( 3.0 ) );
+    const QgsWmsParameter pTitleSpace( QgsWmsParameter::LAYERTITLESPACE, QMetaType::Type::Double, QVariant( 3.0 ) );
     save( pTitleSpace );
 
-    const QgsWmsParameter pSymbHeight( QgsWmsParameter::SYMBOLHEIGHT,
-                                       QMetaType::Type::Double,
-                                       QVariant( 4.0 ) );
+    const QgsWmsParameter pSymbHeight( QgsWmsParameter::SYMBOLHEIGHT, QMetaType::Type::Double, QVariant( 4.0 ) );
     save( pSymbHeight );
 
-    const QgsWmsParameter pSymbWidth( QgsWmsParameter::SYMBOLWIDTH,
-                                      QMetaType::Type::Double,
-                                      QVariant( 7.0 ) );
+    const QgsWmsParameter pSymbWidth( QgsWmsParameter::SYMBOLWIDTH, QMetaType::Type::Double, QVariant( 7.0 ) );
     save( pSymbWidth );
 
-    const QgsWmsParameter pIcLabelSpace( QgsWmsParameter::ICONLABELSPACE,
-                                         QMetaType::Type::Double,
-                                         QVariant( 2.0 ) );
+    const QgsWmsParameter pIcLabelSpace( QgsWmsParameter::ICONLABELSPACE, QMetaType::Type::Double, QVariant( 2.0 ) );
     save( pIcLabelSpace );
 
     const QgsWmsParameter pItFontFamily( QgsWmsParameter::ITEMFONTFAMILY );
     save( pItFontFamily );
 
-    const QgsWmsParameter pItFontBold( QgsWmsParameter::ITEMFONTBOLD,
-                                       QMetaType::Type::Bool,
-                                       QVariant( false ) );
+    const QgsWmsParameter pItFontBold( QgsWmsParameter::ITEMFONTBOLD, QMetaType::Type::Bool, QVariant( false ) );
     save( pItFontBold );
 
-    const QgsWmsParameter pItFontItalic( QgsWmsParameter::ITEMFONTITALIC,
-                                         QMetaType::Type::Bool,
-                                         QVariant( false ) );
+    const QgsWmsParameter pItFontItalic( QgsWmsParameter::ITEMFONTITALIC, QMetaType::Type::Bool, QVariant( false ) );
     save( pItFontItalic );
 
-    const QgsWmsParameter pItFontSize( QgsWmsParameter::ITEMFONTSIZE,
-                                       QMetaType::Type::Double,
-                                       QVariant( -1 ) );
+    const QgsWmsParameter pItFontSize( QgsWmsParameter::ITEMFONTSIZE, QMetaType::Type::Double, QVariant( -1 ) );
     save( pItFontSize );
 
-    const QgsWmsParameter pItFontColor( QgsWmsParameter::ITEMFONTCOLOR,
-                                        QMetaType::Type::QString,
-                                        QVariant( "black" ) );
+    const QgsWmsParameter pItFontColor( QgsWmsParameter::ITEMFONTCOLOR, QMetaType::Type::QString, QVariant( "black" ) );
     save( pItFontColor );
 
     const QgsWmsParameter pHighlightGeom( QgsWmsParameter::HIGHLIGHT_GEOM );
     save( pHighlightGeom );
 
-    const QgsWmsParameter pShowFeatureCount( QgsWmsParameter::SHOWFEATURECOUNT,
-        QMetaType::Type::Bool,
-        QVariant( false ) );
+    const QgsWmsParameter pShowFeatureCount( QgsWmsParameter::SHOWFEATURECOUNT, QMetaType::Type::Bool, QVariant( false ) );
     save( pShowFeatureCount );
 
     const QgsWmsParameter pHighlightSymbol( QgsWmsParameter::HIGHLIGHT_SYMBOL );
@@ -304,9 +275,7 @@ namespace QgsWms
     const QgsWmsParameter pHighlightLabel( QgsWmsParameter::HIGHLIGHT_LABELSTRING );
     save( pHighlightLabel );
 
-    const QgsWmsParameter pHighlightColor( QgsWmsParameter::HIGHLIGHT_LABELCOLOR,
-                                           QMetaType::Type::QString,
-                                           QVariant( "black" ) );
+    const QgsWmsParameter pHighlightColor( QgsWmsParameter::HIGHLIGHT_LABELCOLOR, QMetaType::Type::QString, QVariant( "black" ) );
     save( pHighlightColor );
 
     const QgsWmsParameter pHighlightFontSize( QgsWmsParameter::HIGHLIGHT_LABELSIZE );
@@ -318,9 +287,7 @@ namespace QgsWms
     const QgsWmsParameter pHighlightFont( QgsWmsParameter::HIGHLIGHT_LABELFONT );
     save( pHighlightFont );
 
-    const QgsWmsParameter pHighlightBufferColor( QgsWmsParameter::HIGHLIGHT_LABELBUFFERCOLOR,
-        QMetaType::Type::QString,
-        QVariant( "black" ) );
+    const QgsWmsParameter pHighlightBufferColor( QgsWmsParameter::HIGHLIGHT_LABELBUFFERCOLOR, QMetaType::Type::QString, QVariant( "black" ) );
     save( pHighlightBufferColor );
 
     const QgsWmsParameter pHighlightBufferSize( QgsWmsParameter::HIGHLIGHT_LABELBUFFERSIZE );
@@ -344,70 +311,46 @@ namespace QgsWms
     const QgsWmsParameter pSRS( QgsWmsParameter::SRS );
     save( pSRS );
 
-    const QgsWmsParameter pFormat( QgsWmsParameter::FORMAT,
-                                   QMetaType::Type::QString,
-                                   QVariant( "png" ) );
+    const QgsWmsParameter pFormat( QgsWmsParameter::FORMAT, QMetaType::Type::QString, QVariant( "png" ) );
     save( pFormat );
 
     const QgsWmsParameter pInfoFormat( QgsWmsParameter::INFO_FORMAT );
     save( pInfoFormat );
 
-    const QgsWmsParameter pI( QgsWmsParameter::I,
-                              QMetaType::Type::Int,
-                              QVariant( -1 ) );
+    const QgsWmsParameter pI( QgsWmsParameter::I, QMetaType::Type::Int, QVariant( -1 ) );
     save( pI );
 
-    const QgsWmsParameter pJ( QgsWmsParameter::J,
-                              QMetaType::Type::Int,
-                              QVariant( -1 ) );
+    const QgsWmsParameter pJ( QgsWmsParameter::J, QMetaType::Type::Int, QVariant( -1 ) );
     save( pJ );
 
-    const QgsWmsParameter pX( QgsWmsParameter::X,
-                              QMetaType::Type::Int,
-                              QVariant( -1 ) );
+    const QgsWmsParameter pX( QgsWmsParameter::X, QMetaType::Type::Int, QVariant( -1 ) );
     save( pX );
 
-    const QgsWmsParameter pY( QgsWmsParameter::Y,
-                              QMetaType::Type::Int,
-                              QVariant( -1 ) );
+    const QgsWmsParameter pY( QgsWmsParameter::Y, QMetaType::Type::Int, QVariant( -1 ) );
     save( pY );
 
     const QgsWmsParameter pRule( QgsWmsParameter::RULE );
     save( pRule );
 
-    const QgsWmsParameter pRuleLabel( QgsWmsParameter::RULELABEL,
-                                      QMetaType::Type::Bool,
-                                      QVariant( true ) );
+    const QgsWmsParameter pRuleLabel( QgsWmsParameter::RULELABEL, QMetaType::Type::Bool, QVariant( true ) );
     save( pRuleLabel );
 
-    const QgsWmsParameter pShowRuleDetails( QgsWmsParameter::SHOWRULEDETAILS,
-                                            QMetaType::Type::Bool,
-                                            QVariant( false ) );
+    const QgsWmsParameter pShowRuleDetails( QgsWmsParameter::SHOWRULEDETAILS, QMetaType::Type::Bool, QVariant( false ) );
     save( pShowRuleDetails );
 
-    const QgsWmsParameter pScale( QgsWmsParameter::SCALE,
-                                  QMetaType::Type::Double,
-                                  QVariant( -1 ) );
+    const QgsWmsParameter pScale( QgsWmsParameter::SCALE, QMetaType::Type::Double, QVariant( -1 ) );
     save( pScale );
 
-    const QgsWmsParameter pHeight( QgsWmsParameter::HEIGHT,
-                                   QMetaType::Type::Int,
-                                   QVariant( 0 ) );
+    const QgsWmsParameter pHeight( QgsWmsParameter::HEIGHT, QMetaType::Type::Int, QVariant( 0 ) );
     save( pHeight );
 
-    const QgsWmsParameter pWidth( QgsWmsParameter::WIDTH,
-                                  QMetaType::Type::Int,
-                                  QVariant( 0 ) );
+    const QgsWmsParameter pWidth( QgsWmsParameter::WIDTH, QMetaType::Type::Int, QVariant( 0 ) );
     save( pWidth );
 
-    const QgsWmsParameter pSrcHeight( QgsWmsParameter::SRCHEIGHT,
-                                      QMetaType::Type::Int,
-                                      QVariant( 0 ) );
+    const QgsWmsParameter pSrcHeight( QgsWmsParameter::SRCHEIGHT, QMetaType::Type::Int, QVariant( 0 ) );
     save( pSrcHeight );
 
-    const QgsWmsParameter pSrcWidth( QgsWmsParameter::SRCWIDTH,
-                                     QMetaType::Type::Int,
-                                     QVariant( 0 ) );
+    const QgsWmsParameter pSrcWidth( QgsWmsParameter::SRCWIDTH, QMetaType::Type::Int, QVariant( 0 ) );
     save( pSrcWidth );
 
     const QgsWmsParameter pBbox( QgsWmsParameter::BBOX );
@@ -428,37 +371,25 @@ namespace QgsWms
     const QgsWmsParameter pQueryLayers( QgsWmsParameter::QUERY_LAYERS );
     save( pQueryLayers );
 
-    const QgsWmsParameter pFeatureCount( QgsWmsParameter::FEATURE_COUNT,
-                                         QMetaType::Type::Int,
-                                         QVariant( 1 ) );
+    const QgsWmsParameter pFeatureCount( QgsWmsParameter::FEATURE_COUNT, QMetaType::Type::Int, QVariant( 1 ) );
     save( pFeatureCount );
 
-    const QgsWmsParameter pLayerTitle( QgsWmsParameter::LAYERTITLE,
-                                       QMetaType::Type::Bool,
-                                       QVariant( true ) );
+    const QgsWmsParameter pLayerTitle( QgsWmsParameter::LAYERTITLE, QMetaType::Type::Bool, QVariant( true ) );
     save( pLayerTitle );
 
     const QgsWmsParameter pLayerFtFamily( QgsWmsParameter::LAYERFONTFAMILY );
     save( pLayerFtFamily );
 
-    const QgsWmsParameter pLayerFtBold( QgsWmsParameter::LAYERFONTBOLD,
-                                        QMetaType::Type::Bool,
-                                        QVariant( false ) );
+    const QgsWmsParameter pLayerFtBold( QgsWmsParameter::LAYERFONTBOLD, QMetaType::Type::Bool, QVariant( false ) );
     save( pLayerFtBold );
 
-    const QgsWmsParameter pLayerFtItalic( QgsWmsParameter::LAYERFONTITALIC,
-                                          QMetaType::Type::Bool,
-                                          QVariant( false ) );
+    const QgsWmsParameter pLayerFtItalic( QgsWmsParameter::LAYERFONTITALIC, QMetaType::Type::Bool, QVariant( false ) );
     save( pLayerFtItalic );
 
-    const QgsWmsParameter pLayerFtSize( QgsWmsParameter::LAYERFONTSIZE,
-                                        QMetaType::Type::Double,
-                                        QVariant( -1 ) );
+    const QgsWmsParameter pLayerFtSize( QgsWmsParameter::LAYERFONTSIZE, QMetaType::Type::Double, QVariant( -1 ) );
     save( pLayerFtSize );
 
-    const QgsWmsParameter pLayerFtColor( QgsWmsParameter::LAYERFONTCOLOR,
-                                         QMetaType::Type::QString,
-                                         QVariant( "black" ) );
+    const QgsWmsParameter pLayerFtColor( QgsWmsParameter::LAYERFONTCOLOR, QMetaType::Type::QString, QVariant( "black" ) );
     save( pLayerFtColor );
 
     const QgsWmsParameter pStyle( QgsWmsParameter::STYLE );
@@ -476,42 +407,28 @@ namespace QgsWms
     const QgsWmsParameter pFilterGeom( QgsWmsParameter::FILTER_GEOM );
     save( pFilterGeom );
 
-    const QgsWmsParameter pPolygTol( QgsWmsParameter::FI_POLYGON_TOLERANCE,
-                                     QMetaType::Type::Double,
-                                     QVariant( 0.0 ) );
+    const QgsWmsParameter pPolygTol( QgsWmsParameter::FI_POLYGON_TOLERANCE, QMetaType::Type::Double, QVariant( 0.0 ) );
     save( pPolygTol );
 
-    const QgsWmsParameter pLineTol( QgsWmsParameter::FI_LINE_TOLERANCE,
-                                    QMetaType::Type::Double,
-                                    QVariant( 0.0 ) );
+    const QgsWmsParameter pLineTol( QgsWmsParameter::FI_LINE_TOLERANCE, QMetaType::Type::Double, QVariant( 0.0 ) );
     save( pLineTol );
 
-    const QgsWmsParameter pPointTol( QgsWmsParameter::FI_POINT_TOLERANCE,
-                                     QMetaType::Type::Double,
-                                     QVariant( 0.0 ) );
+    const QgsWmsParameter pPointTol( QgsWmsParameter::FI_POINT_TOLERANCE, QMetaType::Type::Double, QVariant( 0.0 ) );
     save( pPointTol );
 
     const QgsWmsParameter pSelection( QgsWmsParameter::SELECTION );
     save( pSelection );
 
-    const QgsWmsParameter pWmsPrecision( QgsWmsParameter::WMS_PRECISION,
-                                         QMetaType::Type::Int,
-                                         QVariant( -1 ) );
+    const QgsWmsParameter pWmsPrecision( QgsWmsParameter::WMS_PRECISION, QMetaType::Type::Int, QVariant( -1 ) );
     save( pWmsPrecision );
 
-    const QgsWmsParameter pTransparent( QgsWmsParameter::TRANSPARENT,
-                                        QMetaType::Type::Bool,
-                                        QVariant( false ) );
+    const QgsWmsParameter pTransparent( QgsWmsParameter::TRANSPARENT, QMetaType::Type::Bool, QVariant( false ) );
     save( pTransparent );
 
-    const QgsWmsParameter pBgColor( QgsWmsParameter::BGCOLOR,
-                                    QMetaType::Type::QString,
-                                    QVariant( "white" ) );
+    const QgsWmsParameter pBgColor( QgsWmsParameter::BGCOLOR, QMetaType::Type::QString, QVariant( "white" ) );
     save( pBgColor );
 
-    const QgsWmsParameter pDpi( QgsWmsParameter::DPI,
-                                QMetaType::Type::Int,
-                                QVariant( -1 ) );
+    const QgsWmsParameter pDpi( QgsWmsParameter::DPI, QMetaType::Type::Int, QVariant( -1 ) );
     save( pDpi );
 
     const QgsWmsParameter pTemplate( QgsWmsParameter::TEMPLATE );
@@ -520,49 +437,34 @@ namespace QgsWms
     const QgsWmsParameter pExtent( QgsWmsParameter::EXTENT );
     save( pExtent );
 
-    const QgsWmsParameter pRotation( QgsWmsParameter::ROTATION,
-                                     QMetaType::Type::Double,
-                                     QVariant( 0.0 ) );
+    const QgsWmsParameter pRotation( QgsWmsParameter::ROTATION, QMetaType::Type::Double, QVariant( 0.0 ) );
     save( pRotation );
 
-    const QgsWmsParameter pGridX( QgsWmsParameter::GRID_INTERVAL_X,
-                                  QMetaType::Type::Double,
-                                  QVariant( 0.0 ) );
+    const QgsWmsParameter pGridX( QgsWmsParameter::GRID_INTERVAL_X, QMetaType::Type::Double, QVariant( 0.0 ) );
     save( pGridX );
 
-    const QgsWmsParameter pGridY( QgsWmsParameter::GRID_INTERVAL_Y,
-                                  QMetaType::Type::Double,
-                                  QVariant( 0.0 ) );
+    const QgsWmsParameter pGridY( QgsWmsParameter::GRID_INTERVAL_Y, QMetaType::Type::Double, QVariant( 0.0 ) );
     save( pGridY );
 
-    const QgsWmsParameter pWithGeometry( QgsWmsParameter::WITH_GEOMETRY,
-                                         QMetaType::Type::Bool,
-                                         QVariant( false ) );
+    const QgsWmsParameter pWithGeometry( QgsWmsParameter::WITH_GEOMETRY, QMetaType::Type::Bool, QVariant( false ) );
     save( pWithGeometry );
 
-    const QgsWmsParameter pWithMapTip( QgsWmsParameter::WITH_MAPTIP,
-                                       QMetaType::Type::QString );
+    const QgsWmsParameter pWithMapTip( QgsWmsParameter::WITH_MAPTIP, QMetaType::Type::QString );
     save( pWithMapTip );
 
-    const QgsWmsParameter pWithDisplayName( QgsWmsParameter::WITH_DISPLAY_NAME,
-                                            QMetaType::Type::Bool,
-                                            QVariant( false ) );
+    const QgsWmsParameter pWithDisplayName( QgsWmsParameter::WITH_DISPLAY_NAME, QMetaType::Type::Bool, QVariant( false ) );
     save( pWithDisplayName );
 
     const QgsWmsParameter pWmtver( QgsWmsParameter::WMTVER );
     save( pWmtver );
 
-    const QgsWmsParameter pAtlasPk( QgsWmsParameter::ATLAS_PK,
-                                    QMetaType::Type::QStringList );
+    const QgsWmsParameter pAtlasPk( QgsWmsParameter::ATLAS_PK, QMetaType::Type::QStringList );
     save( pAtlasPk );
 
-    const QgsWmsParameter pFormatOpts( QgsWmsParameter::FORMAT_OPTIONS,
-                                       QMetaType::Type::QString );
+    const QgsWmsParameter pFormatOpts( QgsWmsParameter::FORMAT_OPTIONS, QMetaType::Type::QString );
     save( pFormatOpts );
 
-    const QgsWmsParameter pAddLayerGroups( QgsWmsParameter::ADDLAYERGROUPS,
-                                           QMetaType::Type::Bool,
-                                           QVariant( false ) );
+    const QgsWmsParameter pAddLayerGroups( QgsWmsParameter::ADDLAYERGROUPS, QMetaType::Type::Bool, QVariant( false ) );
     save( pAddLayerGroups );
   }
 
@@ -605,7 +507,7 @@ namespace QgsWms
     const thread_local QRegularExpression composerParamRegExp( QStringLiteral( "^MAP\\d+:" ), QRegularExpression::CaseInsensitiveOption );
     if ( key.contains( composerParamRegExp ) )
     {
-      const int mapId = QStringView {key} .mid( 3, key.indexOf( ':' ) - 3 ).toInt();
+      const int mapId = QStringView { key }.mid( 3, key.indexOf( ':' ) - 3 ).toInt();
       const QString theKey = key.mid( key.indexOf( ':' ) + 1 );
       const QgsWmsParameter::Name name = QgsWmsParameter::name( theKey );
 
@@ -615,7 +517,7 @@ namespace QgsWms
         param.mValue = value;
         param.mMapId = mapId;
 
-        if ( ! param.isValid() )
+        if ( !param.isValid() )
         {
           param.raiseError();
         }
@@ -665,7 +567,7 @@ namespace QgsWms
     {
       const QString value = it->toString();
 
-      if ( ! value.isEmpty() )
+      if ( !value.isEmpty() )
       {
         QString name = QgsWmsParameter::name( it.key() );
 
@@ -802,7 +704,7 @@ namespace QgsWms
     }
     else if ( version.isEmpty() )
     {
-      if ( ! wmtver().isEmpty() )
+      if ( !wmtver().isEmpty() )
       {
         version = wmtver();
       }
@@ -868,8 +770,7 @@ namespace QgsWms
     const QString fStr = formatAsString();
 
     Format f = Format::NONE;
-    if ( fStr.compare( QLatin1String( "image/png" ), Qt::CaseInsensitive ) == 0 ||
-         fStr.compare( QLatin1String( "png" ), Qt::CaseInsensitive ) == 0 )
+    if ( fStr.compare( QLatin1String( "image/png" ), Qt::CaseInsensitive ) == 0 || fStr.compare( QLatin1String( "png" ), Qt::CaseInsensitive ) == 0 )
     {
       f = Format::PNG;
     }
@@ -879,19 +780,15 @@ namespace QgsWms
     {
       f = Format::JPG;
     }
-    else if ( fStr.compare( QLatin1String( "image/svg" ), Qt::CaseInsensitive ) == 0 ||
-              fStr.compare( QLatin1String( "image/svg+xml" ), Qt::CaseInsensitive ) == 0 ||
-              fStr.compare( QLatin1String( "svg" ), Qt::CaseInsensitive ) == 0 )
+    else if ( fStr.compare( QLatin1String( "image/svg" ), Qt::CaseInsensitive ) == 0 || fStr.compare( QLatin1String( "image/svg+xml" ), Qt::CaseInsensitive ) == 0 || fStr.compare( QLatin1String( "svg" ), Qt::CaseInsensitive ) == 0 )
     {
       f = Format::SVG;
     }
-    else if ( fStr.compare( QLatin1String( "application/pdf" ), Qt::CaseInsensitive ) == 0 ||
-              fStr.compare( QLatin1String( "pdf" ), Qt::CaseInsensitive ) == 0 )
+    else if ( fStr.compare( QLatin1String( "application/pdf" ), Qt::CaseInsensitive ) == 0 || fStr.compare( QLatin1String( "pdf" ), Qt::CaseInsensitive ) == 0 )
     {
       f = Format::PDF;
     }
-    else if ( fStr.compare( QLatin1String( "application/json" ), Qt::CaseInsensitive ) == 0 ||
-              fStr.compare( QLatin1String( "json" ), Qt::CaseInsensitive ) == 0 )
+    else if ( fStr.compare( QLatin1String( "application/json" ), Qt::CaseInsensitive ) == 0 || fStr.compare( QLatin1String( "json" ), Qt::CaseInsensitive ) == 0 )
     {
       f = Format::JSON;
     }
@@ -1267,7 +1164,7 @@ namespace QgsWms
     font.setBold( layerFontBoldAsBool() );
     font.setItalic( layerFontItalicAsBool() );
 
-    if ( ! layerFontSize().isEmpty() )
+    if ( !layerFontSize().isEmpty() )
       font.setPointSizeF( layerFontSizeAsDouble() );
 
     if ( !layerFontFamily().isEmpty() )
@@ -1284,7 +1181,7 @@ namespace QgsWms
     font.setBold( itemFontBoldAsBool() );
     font.setItalic( itemFontItalicAsBool() );
 
-    if ( ! itemFontSize().isEmpty() )
+    if ( !itemFontSize().isEmpty() )
       font.setPointSizeF( itemFontSizeAsDouble() );
 
     if ( !itemFontFamily().isEmpty() )
@@ -1498,13 +1395,13 @@ namespace QgsWms
     // LAYER
     QList<QgsWmsParameter> cLayer { mWmsParameters.values( QgsWmsParameter::LAYER ) };
     // Sort by map id
-    std::sort( cLayer.begin(), cLayer.end(), []( const QgsWmsParameter & a, const QgsWmsParameter & b ) -> bool { return a.mMapId < b.mMapId; } );
+    std::sort( cLayer.begin(), cLayer.end(), []( const QgsWmsParameter &a, const QgsWmsParameter &b ) -> bool { return a.mMapId < b.mMapId; } );
     for ( const QgsWmsParameter &param : std::as_const( cLayer ) )
     {
       const QStringList layersList { param.toStringList() };
       for ( const QString &layerName : std::as_const( layersList ) )
       {
-        if ( ! result.contains( layerName ) )
+        if ( !result.contains( layerName ) )
           result.append( layerName );
       }
     }
@@ -1512,13 +1409,13 @@ namespace QgsWms
     // LAYERS
     QList<QgsWmsParameter> cLayers { mWmsParameters.values( QgsWmsParameter::LAYERS ) };
     // Sort by map id
-    std::sort( cLayers.begin(), cLayers.end(), []( const QgsWmsParameter & a, const QgsWmsParameter & b ) -> bool { return a.mMapId < b.mMapId; } );
+    std::sort( cLayers.begin(), cLayers.end(), []( const QgsWmsParameter &a, const QgsWmsParameter &b ) -> bool { return a.mMapId < b.mMapId; } );
     for ( const QgsWmsParameter &param : std::as_const( cLayers ) )
     {
       const QStringList layersList { param.toStringList() };
       for ( const QString &layerName : std::as_const( layersList ) )
       {
-        if ( ! result.contains( layerName ) )
+        if ( !result.contains( layerName ) )
           result.append( layerName );
       }
     }
@@ -1547,16 +1444,16 @@ namespace QgsWms
     for ( int i = 0; i < rawFilters.size(); i++ )
     {
       const QString f = rawFilters[i];
-      if ( f.startsWith( QLatin1Char( '<' ) ) \
-           && f.endsWith( QLatin1String( "Filter>" ) ) \
-           &&  i < layers.size() )
+      if ( f.startsWith( QLatin1Char( '<' ) )
+           && f.endsWith( QLatin1String( "Filter>" ) )
+           && i < layers.size() )
       {
         QgsWmsParametersFilter filter;
         filter.mFilter = f;
         filter.mType = QgsWmsParametersFilter::OGC_FE;
         filter.mVersion = QgsOgcUtils::FILTER_OGC_1_0;
 
-        if ( filter.mFilter.contains( nsWfs2 ) \
+        if ( filter.mFilter.contains( nsWfs2 )
              || filter.mFilter.contains( prefixWfs2 ) )
         {
           filter.mVersion = QgsOgcUtils::FILTER_FES_2_0;
@@ -1599,7 +1496,7 @@ namespace QgsWms
 
     if ( options.contains( DxfFormatOption::FORCE_2D ) )
     {
-      force2D = QVariant( options[ DxfFormatOption::FORCE_2D ] ).toBool();
+      force2D = QVariant( options[DxfFormatOption::FORCE_2D] ).toBool();
     }
 
     return force2D;
@@ -1612,7 +1509,7 @@ namespace QgsWms
 
     if ( options.contains( DxfFormatOption::EXPORT_LINES_WITH_ZERO_WIDTH ) )
     {
-      zeroWidth = QVariant( options[ DxfFormatOption::EXPORT_LINES_WITH_ZERO_WIDTH ] ).toBool();
+      zeroWidth = QVariant( options[DxfFormatOption::EXPORT_LINES_WITH_ZERO_WIDTH] ).toBool();
     }
 
     return zeroWidth;
@@ -1625,7 +1522,7 @@ namespace QgsWms
 
     if ( options.contains( DxfFormatOption::NO_MTEXT ) )
     {
-      noMText = QVariant( options[ DxfFormatOption::NO_MTEXT ] ).toBool();
+      noMText = QVariant( options[DxfFormatOption::NO_MTEXT] ).toBool();
     }
 
     return noMText;
@@ -1745,7 +1642,7 @@ namespace QgsWms
         param.mWeight = weights[i];
 
       if ( i < fonts.count() )
-        param.mFont = fonts[ i ];
+        param.mFont = fonts[i];
 
       if ( i < bufferColors.count() )
         param.mBufferColor = bufferColors[i];
@@ -1766,7 +1663,6 @@ namespace QgsWms
         param.mVali = vali[i];
 
 
-
       params.append( param );
     }
 
@@ -1775,7 +1671,7 @@ namespace QgsWms
 
   QList<QgsWmsParametersExternalLayer> QgsWmsParameters::externalLayersParameters() const
   {
-    auto notExternalLayer = []( const QString & name ) { return ! QgsWmsParameters::isExternalLayer( name ); };
+    auto notExternalLayer = []( const QString &name ) { return !QgsWmsParameters::isExternalLayer( name ); };
 
     QList<QgsWmsParametersExternalLayer> externalLayers;
 
@@ -2018,7 +1914,7 @@ namespace QgsWms
         hParam.mWeight = weights[i];
 
       if ( i < fonts.count() )
-        hParam.mFont = fonts[ i ];
+        hParam.mFont = fonts[i];
 
       if ( i < bufferColors.count() )
         hParam.mBufferColor = bufferColors[i];
@@ -2047,7 +1943,6 @@ namespace QgsWms
 
   QString QgsWmsParameters::externalWMSUri( const QString &layerId ) const
   {
-
     // Param names may be uppercased.
     QString id { layerId };
 
@@ -2066,7 +1961,7 @@ namespace QgsWms
     }
 
     QgsDataSourceUri wmsUri;
-    const QMap<QString, QString> &paramMap = mExternalWMSParameters[ id ];
+    const QMap<QString, QString> &paramMap = mExternalWMSParameters[id];
     QMap<QString, QString>::const_iterator paramIt = paramMap.constBegin();
     for ( ; paramIt != paramMap.constEnd(); ++paramIt )
     {
@@ -2135,10 +2030,7 @@ namespace QgsWms
   {
     const QString mStr = withMapTipAsString();
 
-    if ( mStr.startsWith( QLatin1String( "true" ), Qt::CaseInsensitive ) ||
-         mStr.startsWith( QLatin1String( "on" ), Qt::CaseInsensitive ) ||
-         mStr.startsWith( QLatin1String( "yes" ), Qt::CaseInsensitive ) ||
-         mStr.startsWith( QLatin1Char( '1' ) ) )
+    if ( mStr.startsWith( QLatin1String( "true" ), Qt::CaseInsensitive ) || mStr.startsWith( QLatin1String( "on" ), Qt::CaseInsensitive ) || mStr.startsWith( QLatin1String( "yes" ), Qt::CaseInsensitive ) || mStr.startsWith( QLatin1Char( '1' ) ) )
       return true;
     else
       return false;
@@ -2212,7 +2104,7 @@ namespace QgsWms
 
     if ( options.contains( DxfFormatOption::LAYERATTRIBUTES ) )
     {
-      attributes = options[ DxfFormatOption::LAYERATTRIBUTES ].split( ',' );
+      attributes = options[DxfFormatOption::LAYERATTRIBUTES].split( ',' );
     }
 
     return attributes;
@@ -2225,7 +2117,7 @@ namespace QgsWms
 
     if ( options.contains( DxfFormatOption::USE_TITLE_AS_LAYERNAME ) )
     {
-      use = QVariant( options[ DxfFormatOption::USE_TITLE_AS_LAYERNAME ] ).toBool();
+      use = QVariant( options[DxfFormatOption::USE_TITLE_AS_LAYERNAME] ).toBool();
     }
 
     return use;
@@ -2238,7 +2130,7 @@ namespace QgsWms
     double scale = -1;
     if ( options.contains( DxfFormatOption::SCALE ) )
     {
-      scale = options[ DxfFormatOption::SCALE ].toDouble();
+      scale = options[DxfFormatOption::SCALE].toDouble();
     }
 
     return scale;
@@ -2250,12 +2142,12 @@ namespace QgsWms
 
     Qgis::FeatureSymbologyExport symbol = Qgis::FeatureSymbologyExport::NoSymbology;
 
-    if ( ! options.contains( DxfFormatOption::MODE ) )
+    if ( !options.contains( DxfFormatOption::MODE ) )
     {
       return symbol;
     }
 
-    const QString mode = options[ DxfFormatOption::MODE ];
+    const QString mode = options[DxfFormatOption::MODE];
     if ( mode.compare( QLatin1String( "SymbolLayerSymbology" ), Qt::CaseInsensitive ) == 0 )
     {
       symbol = Qgis::FeatureSymbologyExport::PerSymbolLayer;
@@ -2274,21 +2166,21 @@ namespace QgsWms
 
     if ( formatOptions<QgsWmsParameters::DxfFormatOption>().contains( DxfFormatOption::CODEC ) )
     {
-      codec = formatOptions<QgsWmsParameters::DxfFormatOption>()[ DxfFormatOption::CODEC ];
+      codec = formatOptions<QgsWmsParameters::DxfFormatOption>()[DxfFormatOption::CODEC];
     }
 
     return codec;
   }
 
-  bool QgsWmsParameters::writeGeoPdf() const
+  bool QgsWmsParameters::writeGeospatialPdf() const
   {
-    bool geoPdf = false;
+    bool geospatialPdf = false;
     const QMap<QgsWmsParameters::PdfFormatOption, QString> options = formatOptions<QgsWmsParameters::PdfFormatOption>();
     if ( options.contains( PdfFormatOption::WRITE_GEO_PDF ) )
     {
-      geoPdf = QVariant( options[PdfFormatOption::WRITE_GEO_PDF] ).toBool();
+      geospatialPdf = QVariant( options[PdfFormatOption::WRITE_GEO_PDF] ).toBool();
     }
-    return geoPdf;
+    return geospatialPdf;
   }
 
   bool QgsWmsParameters::pdfForceVectorOutput() const
@@ -2345,6 +2237,10 @@ namespace QgsWms
       {
         format = Qgis::TextRenderFormat::AlwaysText;
       }
+      else if ( options[PdfFormatOption::TEXT_RENDER_FORMAT].compare( QStringLiteral( "PreferText" ), Qt::CaseInsensitive ) == 0 )
+      {
+        format = Qgis::TextRenderFormat::PreferText;
+      }
     }
     return format;
   }
@@ -2442,4 +2338,4 @@ namespace QgsWms
     }
     return dimValues;
   }
-}
+} // namespace QgsWms
