@@ -49,7 +49,7 @@ namespace QTest
     QByteArray ba = geom.asWkt().toLatin1();
     return qstrdup( ba.data() );
   }
-}
+} // namespace QTest
 
 /**
  * \ingroup UnitTests
@@ -62,8 +62,8 @@ class TestQgsVertexTool : public QObject
     TestQgsVertexTool();
 
   private slots:
-    void initTestCase();// will be called before the first testfunction is executed.
-    void cleanupTestCase();// will be called after the last testfunction was executed.
+    void initTestCase();    // will be called before the first testfunction is executed.
+    void cleanupTestCase(); // will be called after the last testfunction was executed.
 
     void testSelectVerticesByPolygon();
     void testTopologicalEditingMoveVertexZ();
@@ -92,6 +92,7 @@ class TestQgsVertexTool : public QObject
     void testActiveLayerPriority();
     void testSelectedFeaturesPriority();
     void testVertexToolCompoundCurve();
+    void testMoveVertexTopoOtherMapCrs();
 
   private:
     QPoint mapToScreen( double mapX, double mapY )
@@ -260,37 +261,37 @@ void TestQgsVertexTool::initTestCase()
   mLayerLine->startEditing();
   mLayerLine->addFeature( lineF1 );
   mFidLineF1 = lineF1.id();
-  QCOMPARE( mLayerLine->featureCount(), ( long )1 );
+  QCOMPARE( mLayerLine->featureCount(), ( long ) 1 );
 
   mLayerMultiLine->startEditing();
   mLayerMultiLine->addFeature( multiLineF1 );
   mFidMultiLineF1 = multiLineF1.id();
-  QCOMPARE( mLayerMultiLine->featureCount(), ( long )1 );
+  QCOMPARE( mLayerMultiLine->featureCount(), ( long ) 1 );
 
   mLayerLineReprojected->startEditing();
   mLayerLineReprojected->addFeature( lineF13857 );
   mFidLineF13857 = lineF13857.id();
-  QCOMPARE( mLayerLineReprojected->featureCount(), ( long )1 );
+  QCOMPARE( mLayerLineReprojected->featureCount(), ( long ) 1 );
 
   mLayerPolygon->startEditing();
   mLayerPolygon->addFeature( polygonF1 );
   mFidPolygonF1 = polygonF1.id();
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 1 );
 
   mLayerMultiPolygon->startEditing();
   mLayerMultiPolygon->addFeature( multiPolygonF1 );
   mFidMultiPolygonF1 = multiPolygonF1.id();
-  QCOMPARE( mLayerMultiPolygon->featureCount(), ( long )1 );
+  QCOMPARE( mLayerMultiPolygon->featureCount(), ( long ) 1 );
 
   mLayerPoint->startEditing();
   mLayerPoint->addFeature( pointF1 );
   mFidPointF1 = pointF1.id();
-  QCOMPARE( mLayerPoint->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPoint->featureCount(), ( long ) 1 );
 
   mLayerPointZ->startEditing();
   mLayerPointZ->addFeature( pointZF1 );
   mFidPointZF1 = pointZF1.id();
-  QCOMPARE( mLayerPointZ->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPointZ->featureCount(), ( long ) 1 );
 
   mLayerLineZ->startEditing();
   mLayerLineZ->addFeature( linez1 );
@@ -628,7 +629,7 @@ void TestQgsVertexTool::testMovePointAddingZ()
   QgsFeature pointZF2;
   pointZF2.setGeometry( QgsGeometry::fromWkt( "Point (30 35)" ) );
   mLayerPointZ->addFeature( pointZF2 );
-  QCOMPARE( mLayerPointZ->featureCount(), ( long )2 );
+  QCOMPARE( mLayerPointZ->featureCount(), ( long ) 2 );
   QCOMPARE( mLayerPointZ->undoStack()->index(), 2 );
 
   // And snap on a point with Z
@@ -737,7 +738,6 @@ void TestQgsVertexTool::testAddVertexAtEndpoint()
   QCOMPARE( mLayerLine->undoStack()->index(), 1 );
 
   QCOMPARE( mLayerLine->getFeature( mFidLineF1 ).geometry(), QgsGeometry::fromWkt( "LINESTRING(2 1, 1 1, 1 3)" ) );
-
 }
 
 void TestQgsVertexTool::testAddVertexDoubleClick()
@@ -770,7 +770,6 @@ void TestQgsVertexTool::testAddVertexDoubleClick()
   QCOMPARE( mLayerLine->undoStack()->index(), 1 );
   QCOMPARE( mLayerPolygon->undoStack()->index(), 1 );
   QCOMPARE( mLayerPoint->undoStack()->index(), 1 );
-
 }
 
 void TestQgsVertexTool::testAddVertexDoubleClickWithShift()
@@ -801,7 +800,6 @@ void TestQgsVertexTool::testAddVertexDoubleClickWithShift()
   QCOMPARE( mLayerLine->undoStack()->index(), 1 );
   QCOMPARE( mLayerPolygon->undoStack()->index(), 1 );
   QCOMPARE( mLayerPoint->undoStack()->index(), 1 );
-
 }
 
 void TestQgsVertexTool::testDeleteVertex()
@@ -1034,7 +1032,7 @@ void TestQgsVertexTool::testMoveVertexTopo()
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "POLYGON((3 3, 7 1, 7 4, 4 4, 3 3))" ) );
 
   QCOMPARE( mLayerLine->undoStack()->index(), 2 );
-  QCOMPARE( mLayerPolygon->undoStack()->index(), 3 );  // one more move of vertex from earlier
+  QCOMPARE( mLayerPolygon->undoStack()->index(), 3 ); // one more move of vertex from earlier
   mLayerLine->undoStack()->undo();
   mLayerPolygon->undoStack()->undo();
   mLayerPolygon->undoStack()->undo();
@@ -1063,7 +1061,7 @@ void TestQgsVertexTool::testDeleteVertexTopo()
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "POLYGON((7 1, 7 4, 4 4, 7 1))" ) );
 
   QCOMPARE( mLayerLine->undoStack()->index(), 2 );
-  QCOMPARE( mLayerPolygon->undoStack()->index(), 3 );  // one more move of vertex from earlier
+  QCOMPARE( mLayerPolygon->undoStack()->index(), 3 ); // one more move of vertex from earlier
   mLayerLine->undoStack()->undo();
   mLayerPolygon->undoStack()->undo();
   mLayerPolygon->undoStack()->undo();
@@ -1243,7 +1241,7 @@ void TestQgsVertexTool::testAddVertexTopoMultipleLayers()
 void TestQgsVertexTool::testAvoidIntersections()
 {
   // There is one feature in the layer
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 1 );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "Polygon ((4 1, 7 1, 7 4, 4 4, 4 1))" ) ); // avoid rounding errors
 
   QgsProject::instance()->setTopologicalEditing( true );
@@ -1266,7 +1264,7 @@ void TestQgsVertexTool::testAvoidIntersections()
   const QgsFeatureId mFidPolygonF2 = polygonF2.id();
 
   // Starting point
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )2 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 2 );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "Polygon ((4 1, 7 1, 7 4, 4 4, 4 1))" ) );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF2 ).geometry(), QgsGeometry::fromWkt( "Polygon ((8 2, 9 2, 9 3, 8 3, 8 2))" ) );
 
@@ -1281,7 +1279,7 @@ void TestQgsVertexTool::testAvoidIntersections()
 
   QCOMPARE( spy.count(), 1 ); // 1 for the moved vertex
 
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )2 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 2 );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "Polygon ((4 1, 7 1, 7 4, 5 5, 4 1))" ) );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF2 ).geometry(), QgsGeometry::fromWkt( "Polygon ((8 2, 9 2, 9 3, 8 3, 8 2))" ) );
 
@@ -1297,7 +1295,7 @@ void TestQgsVertexTool::testAvoidIntersections()
 
   QCOMPARE( spy.count(), 1 ); // 1 for the moved vertex
 
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )2 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 2 );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "Polygon ((4 4, 7 4, 8 3, 8 2, 9 2, 4 1, 4 4))" ) );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF2 ).geometry(), QgsGeometry::fromWkt( "Polygon ((8 2, 9 2, 9 3, 8 3, 8 2))" ) );
 
@@ -1330,7 +1328,7 @@ void TestQgsVertexTool::testAvoidIntersections()
 
   mLayerPolygon->undoStack()->undo(); // delete feature
 
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 1 );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "POLYGON((4 1, 7 1, 7 4, 4 4, 4 1))" ) );
 
   QCOMPARE( mLayerPolygon->undoStack()->index(), 1 );
@@ -1357,7 +1355,7 @@ void TestQgsVertexTool::testAvoidIntersections()
   mLayerPolygon->addFeature( polygonF_topo2 );
   const QgsFeatureId mFidPolygonF_topo2 = polygonF_topo2.id();
 
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )3 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 3 );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "Polygon ((4 1, 7 1, 7 4, 4 4, 4 1))" ) );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF_topo1 ).geometry(), QgsGeometry::fromWkt( "Polygon ((0 10, 0 20, 5 15, 0 10))" ) );
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF_topo2 ).geometry(), QgsGeometry::fromWkt( "Polygon ((10 15, 15 10, 15 20, 10 15))" ) );
@@ -1372,7 +1370,7 @@ void TestQgsVertexTool::testAvoidIntersections()
   mLayerPolygon->undoStack()->undo(); // undo move and topological points
   mLayerPolygon->undoStack()->undo(); // delete feature polygonF_topo2
   mLayerPolygon->undoStack()->undo(); // delete feature polygonF_topo1
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 1 );
 
   // Make sure the largest part is preserved if multiple parts are created
   polygonF2.setGeometry( QgsGeometry::fromWkt( "Polygon ((8 3, 9 3, 9 2, 8 2, 8 3))" ) );
@@ -1385,7 +1383,7 @@ void TestQgsVertexTool::testAvoidIntersections()
   mLayerPolygon->undoStack()->undo(); // undo edge move
   mLayerPolygon->undoStack()->undo(); // undo feature addition
 
-  QCOMPARE( mLayerPolygon->featureCount(), ( long )1 );
+  QCOMPARE( mLayerPolygon->featureCount(), ( long ) 1 );
 
   QgsProject::instance()->setTopologicalEditing( false );
   QgsProject::instance()->setAvoidIntersectionsMode( mode );
@@ -1447,7 +1445,7 @@ void TestQgsVertexTool::testActiveLayerPriority()
   layerLine2->startEditing();
   layerLine2->addFeature( lineF1 );
   const QgsFeatureId fidLineF1 = lineF1.id();
-  QCOMPARE( layerLine2->featureCount(), ( long )1 );
+  QCOMPARE( layerLine2->featureCount(), ( long ) 1 );
   QgsProject::instance()->addMapLayer( layerLine2 );
   QList<QgsMapLayer *> oldMapLayers = mCanvas->layers();
   mCanvas->setLayers( QList<QgsMapLayer *>() << mLayerLine << mLayerPolygon << mLayerPoint << mLayerCompoundCurve << layerLine2 );
@@ -1560,7 +1558,7 @@ void TestQgsVertexTool::testSelectedFeaturesPriority()
   QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "POLYGON((7 1, 7 4, 4 4, 7 1))" ) );
   mLayerPolygon->undoStack()->undo();
 
-  mLayerPolygon->undoStack()->undo();  // undo the initial change
+  mLayerPolygon->undoStack()->undo(); // undo the initial change
 }
 
 void TestQgsVertexTool::testVertexToolCompoundCurve()
@@ -1590,8 +1588,7 @@ void TestQgsVertexTool::testVertexToolCompoundCurve()
   mouseClick( 18, 17, Qt::LeftButton );
 
   QCOMPARE( mLayerCompoundCurve->undoStack()->index(), 3 );
-  QCOMPARE( mLayerCompoundCurve->getFeature( mFidCompoundCurveF1 ).geometry(),
-            QgsGeometry::fromWkt( "CompoundCurve ( CircularString (14 14, 18 17, 13.75126265847083928 13.78427124746189492, 10 10, 17 10))" ) );
+  QCOMPARE( mLayerCompoundCurve->getFeature( mFidCompoundCurveF1 ).geometry(), QgsGeometry::fromWkt( "CompoundCurve ( CircularString (14 14, 18 17, 13.75126265847083928 13.78427124746189492, 10 10, 17 10))" ) );
 
   mLayerCompoundCurve->undoStack()->undo();
 
@@ -1614,7 +1611,6 @@ void TestQgsVertexTool::testVertexToolCompoundCurve()
   mouseMove( 17, 10 );
   mouseClick( 17 + offsetInMapUnits, 10, Qt::LeftButton );
   mouseClick( 7, 2, Qt::LeftButton );
-  mouseClick( 7, 1, Qt::RightButton );
 
   // verifying that it's not possible to add a extra vertex to a CircularString
   QCOMPARE( mLayerCompoundCurve->undoStack()->index(), 2 );
@@ -1647,5 +1643,47 @@ void TestQgsVertexTool::testSelectVerticesByPolygon()
   QCOMPARE( mLayerMultiPolygon->getFeature( mFidMultiPolygonF1 ).geometry(), QgsGeometry::fromWkt( "MultiPolygon (((1 5, 2 5, 2 6.5, 2 8, 1 8, 1 6.5, 1 5),(1.25 5.5, 1.25 6, 1.75 6, 1.75 5.5, 1.25 5.5),(1.25 7, 1.75 7, 1.75 7.5, 1.25 7.5, 1.25 7)),((3 5, 3 6.5, 3 8, 4 8, 4 6.5, 4 5, 3 5),(3.25 5.5, 3.75 5.5, 3.75 6, 3.25 6, 3.25 5.5),(3.25 7, 3.75 7, 3.75 7.5, 3.25 7.5, 3.25 7)))" ) );
 }
 
+void TestQgsVertexTool::testMoveVertexTopoOtherMapCrs()
+{
+  // test moving of vertices of two features at once
+
+  QgsProject::instance()->setTopologicalEditing( true );
+  QgsCoordinateReferenceSystem prevCrs = QgsProject::instance()->crs();
+  QgsCoordinateReferenceSystem tmpCrs = QgsCoordinateReferenceSystem( QStringLiteral( "EPSG:3857" ) );
+
+  // move linestring vertex to connect with polygon at point (7, 1)
+  mouseClick( 2, 1, Qt::LeftButton );
+  mouseClick( 7, 1, Qt::LeftButton );
+
+  // change CRS so that the map canvas and the layers CRSs are different
+  mCanvas->setDestinationCrs( tmpCrs );
+  mCanvas->snappingUtils()->locatorForLayer( mLayerLine )->init();
+  mCanvas->snappingUtils()->locatorForLayer( mLayerPolygon )->init();
+
+  // Start point is 7, 1 in layer coordinates, to snap to the linestring and polygon vertices.
+  // End point is 3, 3 in layer coordinates.
+  // Get the map coordinates for these points to click on it.
+  QgsPointXY mapPointStart = mCanvas->mapSettings().layerToMapCoordinates( mLayerPolygon, QgsPointXY( 7, 1 ) );
+  QgsPointXY mapPointEnd = mCanvas->mapSettings().layerToMapCoordinates( mLayerPolygon, QgsPointXY( 3, 3 ) );
+  mouseClick( mapPointStart.x(), mapPointStart.y(), Qt::LeftButton );
+  mouseClick( mapPointEnd.x(), mapPointEnd.y(), Qt::LeftButton );
+
+  // polygon and line features have changed, within the CRS conversion precision
+  QCOMPARE( mLayerLine->getFeature( mFidLineF1 ).geometry().asWkt( 2 ), "LineString (3 3, 1 1, 1 3)" );
+  QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry().asWkt( 2 ), "Polygon ((4 1, 3 3, 7 4, 4 4, 4 1))" );
+
+  QCOMPARE( mLayerLine->undoStack()->index(), 3 ); // one more move of vertex from earlier
+  QCOMPARE( mLayerPolygon->undoStack()->index(), 2 );
+  mLayerLine->undoStack()->undo();
+  mLayerLine->undoStack()->undo();
+  mLayerPolygon->undoStack()->undo();
+
+  // back to the original state
+  QCOMPARE( mLayerLine->getFeature( mFidLineF1 ).geometry(), QgsGeometry::fromWkt( "LINESTRING(2 1, 1 1, 1 3)" ) );
+  QCOMPARE( mLayerPolygon->getFeature( mFidPolygonF1 ).geometry(), QgsGeometry::fromWkt( "POLYGON((4 1, 7 1, 7 4, 4 4, 4 1))" ) );
+  mCanvas->setDestinationCrs( prevCrs );
+  QgsProject::instance()->setTopologicalEditing( false );
+}
+
 QGSTEST_MAIN( TestQgsVertexTool )
 #include "testqgsvertextool.moc"
