@@ -23,7 +23,7 @@
  * \ingroup UnitTests
  * This is a unit test for the WMS capabilities parser.
  */
-class TestQgsWmsCapabilities: public QObject
+class TestQgsWmsCapabilities : public QObject
 {
     Q_OBJECT
   private slots:
@@ -72,12 +72,10 @@ class TestQgsWmsCapabilities: public QObject
       QCOMPARE( capabilities.supportedLayers()[0].style.size(), 2 );
       QCOMPARE( capabilities.supportedLayers()[0].style[0].name, QString( "yt_style" ) );
       QCOMPARE( capabilities.supportedLayers()[0].style[0].legendUrl.size(), 1 );
-      QCOMPARE( capabilities.supportedLayers()[0].style[0].legendUrl[0].onlineResource.xlinkHref,
-                QString( "http://www.example.com/yt.png" ) );
+      QCOMPARE( capabilities.supportedLayers()[0].style[0].legendUrl[0].onlineResource.xlinkHref, QString( "http://www.example.com/yt.png" ) );
       QCOMPARE( capabilities.supportedLayers()[0].style[1].name, QString( "fb_style" ) );
       QCOMPARE( capabilities.supportedLayers()[0].style[1].legendUrl.size(), 1 );
-      QCOMPARE( capabilities.supportedLayers()[0].style[1].legendUrl[0].onlineResource.xlinkHref,
-                QString( "http://www.example.com/fb.png" ) );
+      QCOMPARE( capabilities.supportedLayers()[0].style[1].legendUrl[0].onlineResource.xlinkHref, QString( "http://www.example.com/fb.png" ) );
 
       QCOMPARE( capabilities.supportedLayers()[0].crs, QStringList() << QStringLiteral( "EPSG:2056" ) );
     }
@@ -96,16 +94,13 @@ class TestQgsWmsCapabilities: public QObject
       QCOMPARE( capabilities.supportedLayers().size(), 5 );
 
       QCOMPARE( capabilities.supportedLayers().at( 0 ).preferredAvailableCrs(), QStringLiteral( "EPSG:3857" ) );
-
     }
 
     void wmstSettings()
     {
       QgsWmsSettings settings = QgsWmsSettings();
 
-      QMap<QString, QString> map = { { "2020-02-13T12:00:00Z", "yyyy-MM-ddThh:mm:ssZ" },
-        { "2020-02-13", "yyyy-MM-dd" }
-      };
+      QMap<QString, QString> map = { { "2020-02-13T12:00:00Z", "yyyy-MM-ddThh:mm:ssZ" }, { "2020-02-13", "yyyy-MM-dd" } };
       QMapIterator<QString, QString> iterator( map );
 
       while ( iterator.hasNext() )
@@ -115,8 +110,7 @@ class TestQgsWmsCapabilities: public QObject
         QCOMPARE( date.toString( iterator.value() ), iterator.key() );
       }
 
-      QList<QString> resolutionList =
-      {
+      QList<QString> resolutionList = {
         "P1D", "P1Y", "PT5M", "P1DT1H",
         "P1Y1DT3S", "P1MT1M", "PT23H3M", "P26DT23H3M", "PT30S"
       };
@@ -230,18 +224,18 @@ class TestQgsWmsCapabilities: public QObject
       QCOMPARE( extent.datesResolutionList.at( 7 ).dates.dateTimes.size(), 1 );
       QCOMPARE( extent.datesResolutionList.at( 7 ).dates.dateTimes.at( 0 ), QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
 
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1930, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1930, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1932, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1933, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1947, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1947, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1949, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1947, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1950, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1950, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1950, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1950, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1973, 12, 31 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1972, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1974, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
-      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 2000, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ),  QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1930, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1930, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1932, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1933, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1932, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1947, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1947, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1949, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1947, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1950, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1950, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1950, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1950, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1973, 12, 31 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1972, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 1974, 1, 2 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
+      QCOMPARE( settings.findLeastClosestDateTime( QDateTime( QDate( 2000, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) ), QDateTime( QDate( 1974, 1, 1 ), QTime( 0, 0, 0 ), Qt::UTC ) );
     }
 
     void wmsTemporalDimension_data()
@@ -259,10 +253,10 @@ class TestQgsWmsCapabilities: public QObject
                                      </Dimension>)"""
                                   << "2020-01-01/2020-12-31/P1M";
 
-      QTest::newRow( "list" )     << R"""(<Dimension name="time" units="ISO8601">
+      QTest::newRow( "list" ) << R"""(<Dimension name="time" units="ISO8601">
                                      2020-01-01,2020-06-31,2020-12-31
                                      </Dimension>)"""
-                                  << "2020-01-01,2020-06-31,2020-12-31";
+                              << "2020-01-01,2020-06-31,2020-12-31";
 
       QTest::newRow( "continuous" ) << R"""(<Dimension name="time" units="ISO8601">
                                      2020-01-01/2020-06-31
@@ -270,11 +264,11 @@ class TestQgsWmsCapabilities: public QObject
                                     << "2020-01-01/2020-06-31";
 
       QTest::newRow( "interval with internal newline characters" )
-          << R"""(<Dimension name="time" units="ISO8601">
+        << R"""(<Dimension name="time" units="ISO8601">
              2020-01-01/2020-06-31/P1M,
              2020-07-01/2020-12-31/P1D
              </Dimension>)"""
-          << "2020-01-01/2020-06-31/P1M, 2020-07-01/2020-12-31/P1D";
+        << "2020-01-01/2020-06-31/P1M, 2020-07-01/2020-12-31/P1D";
     }
 
     void wmsTemporalDimension()
@@ -412,7 +406,7 @@ class TestQgsWmsCapabilities: public QObject
                                                        2020-01-01
                                                        </Dimension>
                                                        </Layer>)"""
-          << R"""(<Layer queryable="0" opaque="0" cascaded="0">
+                                                    << R"""(<Layer queryable="0" opaque="0" cascaded="0">
                                                        <Name>Test</Name>
                                                        <Title>Test</Title>
                                                        <Abstract>Test</Abstract>
@@ -424,7 +418,7 @@ class TestQgsWmsCapabilities: public QObject
                                                        2020-01-01/2020-12-31/P1M
                                                        </Dimension>
                                                        </Layer>)"""
-          << false;
+                                                    << false;
     }
 
     void wmsLayerProperty()
@@ -447,7 +441,6 @@ class TestQgsWmsCapabilities: public QObject
       cap.parseLayer( doc2.documentElement(), secondLayerProp );
 
       QCOMPARE( firstLayerProp.equal( secondLayerProp ), result );
-
     }
 
     void wmsIdentifyFormat_data()
@@ -567,13 +560,12 @@ class TestQgsWmsCapabilities: public QObject
       QCOMPARE( tileLayer.title, QStringLiteral( "ETa Scaled" ) );
       QCOMPARE( tileLayer.timeDimensionIdentifier, QStringLiteral( "time" ) );
 
-      QCOMPARE( tileLayer.allTimeRanges, QList< QgsDateTimeRange >(
-      {
-        QgsDateTimeRange( QDateTime( QDate( 2005, 8, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2005, 8, 1 ), QTime( 0, 0, 0 ) ) ),
-        QgsDateTimeRange( QDateTime( QDate( 2016, 3, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2016, 3, 1 ), QTime( 0, 0, 0 ) ) ),
-        QgsDateTimeRange( QDateTime( QDate( 2005, 7, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2005, 7, 1 ), QTime( 0, 0, 0 ) ) ),
-        QgsDateTimeRange( QDateTime( QDate( 2009, 2, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2009, 2, 1 ), QTime( 0, 0, 0 ) ) ),
-      } ) );
+      QCOMPARE( tileLayer.allTimeRanges, QList<QgsDateTimeRange>( {
+                                           QgsDateTimeRange( QDateTime( QDate( 2005, 8, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2005, 8, 1 ), QTime( 0, 0, 0 ) ) ),
+                                           QgsDateTimeRange( QDateTime( QDate( 2016, 3, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2016, 3, 1 ), QTime( 0, 0, 0 ) ) ),
+                                           QgsDateTimeRange( QDateTime( QDate( 2005, 7, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2005, 7, 1 ), QTime( 0, 0, 0 ) ) ),
+                                           QgsDateTimeRange( QDateTime( QDate( 2009, 2, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2009, 2, 1 ), QTime( 0, 0, 0 ) ) ),
+                                         } ) );
       QCOMPARE( tileLayer.temporalExtent, QgsDateTimeRange( QDateTime( QDate( 2005, 7, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2016, 3, 1 ), QTime( 0, 0, 0 ) ) ) );
       QCOMPARE( tileLayer.temporalInterval, QgsInterval( 1, Qgis::TemporalUnit::IrregularStep ) );
       QCOMPARE( tileLayer.temporalCapabilityFlags, Qgis::RasterTemporalCapabilityFlag::RequestedTimesMustExactlyMatchAllAvailableTemporalRanges );
@@ -586,10 +578,10 @@ class TestQgsWmsCapabilities: public QObject
       QTest::addColumn<QgsDateTimeRange>( "range" );
       QTest::addColumn<int>( "format" );
 
-      QTest::newRow( "YYYYMMDD" ) << QString( "20210103" ) << QgsDateTimeRange( QDateTime( QDate( 2021, 1, 3 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2021, 1, 3 ), QTime( 23, 59, 59, 999 ) ) ) << static_cast< int >( QgsWmtsTileLayer::WmtsTimeFormat::yyyyMMdd );
-      QTest::newRow( "YYYY-MM-DD" ) << QString( "2021-01-03" ) << QgsDateTimeRange( QDateTime( QDate( 2021, 1, 3 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2021, 1, 3 ), QTime( 23, 59, 59, 999 ) ) ) << static_cast< int >( QgsWmtsTileLayer::WmtsTimeFormat::yyyy_MM_dd );
-      QTest::newRow( "YYYY" ) << QString( "2021" ) << QgsDateTimeRange( QDateTime( QDate( 2021, 1, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2021, 12, 31 ), QTime( 23, 59, 59, 999 ) ) ) << static_cast< int >( QgsWmtsTileLayer::WmtsTimeFormat::yyyy );
-      QTest::newRow( "YYYY-MM-DDTHH:mm:ss.SSSZ" ) << QString( "2018-03-01T16:23:44Z" ) << QgsDateTimeRange( QDateTime( QDate( 2018, 3, 1 ), QTime( 16, 23, 44 ) ), QDateTime( QDate( 2018, 3, 1 ), QTime( 16, 23, 44 ) ) ) << static_cast< int >( QgsWmtsTileLayer::WmtsTimeFormat::yyyyMMddThhmmssZ );
+      QTest::newRow( "YYYYMMDD" ) << QString( "20210103" ) << QgsDateTimeRange( QDateTime( QDate( 2021, 1, 3 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2021, 1, 3 ), QTime( 23, 59, 59, 999 ) ) ) << static_cast<int>( QgsWmtsTileLayer::WmtsTimeFormat::yyyyMMdd );
+      QTest::newRow( "YYYY-MM-DD" ) << QString( "2021-01-03" ) << QgsDateTimeRange( QDateTime( QDate( 2021, 1, 3 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2021, 1, 3 ), QTime( 23, 59, 59, 999 ) ) ) << static_cast<int>( QgsWmtsTileLayer::WmtsTimeFormat::yyyy_MM_dd );
+      QTest::newRow( "YYYY" ) << QString( "2021" ) << QgsDateTimeRange( QDateTime( QDate( 2021, 1, 1 ), QTime( 0, 0, 0 ) ), QDateTime( QDate( 2021, 12, 31 ), QTime( 23, 59, 59, 999 ) ) ) << static_cast<int>( QgsWmtsTileLayer::WmtsTimeFormat::yyyy );
+      QTest::newRow( "YYYY-MM-DDTHH:mm:ss.SSSZ" ) << QString( "2018-03-01T16:23:44Z" ) << QgsDateTimeRange( QDateTime( QDate( 2018, 3, 1 ), QTime( 16, 23, 44 ) ), QDateTime( QDate( 2018, 3, 1 ), QTime( 16, 23, 44 ) ) ) << static_cast<int>( QgsWmtsTileLayer::WmtsTimeFormat::yyyyMMddThhmmssZ );
     }
 
     void wmtsTimeDimensionValue()
@@ -602,9 +594,8 @@ class TestQgsWmsCapabilities: public QObject
       QgsDateTimeRange res = QgsWmsSettings::parseWmtsTimeValue( value, resFormat );
       QCOMPARE( res.begin(), range.begin() );
       QCOMPARE( res.end(), range.end() );
-      QCOMPARE( static_cast< int >( resFormat ), format );
+      QCOMPARE( static_cast<int>( resFormat ), format );
     }
-
 };
 
 QGSTEST_MAIN( TestQgsWmsCapabilities )
